@@ -1,6 +1,6 @@
 //* @file app_dynamic_features.h */
 
-// Copyright (C) 2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2018-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef APP_DYNAMIC_FEATURES_H_
@@ -8,6 +8,7 @@
 
 #include "base/displays.h"
 
-void check_dynamic_features(Display_Ref * dref);
+void app_check_dynamic_features(Display_Ref * dref);
+void init_app_dynamic_features();
 
 #endif /* APP_DYNAMIC_FEATURES_H_ */
