@@ -12,6 +12,7 @@
 #include "util/timestamp.h"
 
 #include "i2c/i2c_bus_core.h"
+#include "i2c/i2c_edid.h"
 #include "i2c/i2c_strategy_dispatcher.h"
 
 #include "ddc/ddc_display_ref_reports.h"
@@ -29,11 +30,11 @@ void
 report_experimental_options(Parsed_Cmd * parsed_cmd, int depth)
 {
    rpt_label(depth, "Experimental Options:");
-   REPORT_FLAG_OPTION(1, "Unused");
+   REPORT_FLAG_OPTION(1, "Suppress SE_POST_READ");
    REPORT_FLAG_OPTION(2, "Experimental sysfs analysis");    // was Filter phantom displays
    REPORT_FLAG_OPTION(3, "Unused");
    REPORT_FLAG_OPTION(4, "Read strategy tests");
-   REPORT_FLAG_OPTION(5, "Unused");
+   REPORT_FLAG_OPTION(5, "EDID read does not use I2C layer");
    REPORT_FLAG_OPTION(6, "Force I2C bus");
 
    rpt_vstring(depth+1, "Utility option --i1 = %d:     Unused", parsed_cmd->i1);
