@@ -3,13 +3,14 @@
  *  ddcutil standalone application mainline
  */
 
-// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2023 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
 #include <config.h>
 
 #include <assert.h>
+#include <base/base_services.h>
 #include <ctype.h>
 #include <errno.h>
 #include <glib-2.0/glib.h>
@@ -20,7 +21,9 @@
 
 #include <stdlib.h>
 #include <string.h>
+#ifdef ENABLE_SYSLOG
 #include <syslog.h>
+#endif
 #include <unistd.h>
 
 #include "util/data_structures.h"
@@ -43,7 +46,6 @@
 
 #include "public/ddcutil_types.h"
 
-#include "base/base_init.h"
 #include "base/build_info.h"
 #include "base/core.h"
 #include "base/ddc_errno.h"
@@ -71,6 +73,7 @@
 
 #include "i2c/i2c_bus_core.h"
 #include "i2c/i2c_strategy_dispatcher.h"
+#include "i2c/i2c_sysfs.h"
 
 #ifdef USE_USB
 #include "usb/usb_displays.h"
@@ -145,6 +148,8 @@ report_performance_options(int depth)
 
 static void
 report_optional_features(Parsed_Cmd * parsed_cmd, int depth) {
+   rpt_vstring( depth, "%.*s%-*s%s", 0, "", 28, "Force I2C slave address:",
+                       sbool(i2c_forceable_slave_addr_flag));
    rpt_vstring( depth, "%.*s%-*s%s", 0, "", 28, "User defined features:",
                        (enable_dynamic_features) ? "enabled" : "disabled" );
                        // "Enable user defined features" is too long a title
@@ -165,7 +170,7 @@ report_all_options(Parsed_Cmd * parsed_cmd, char * config_fn, char * default_opt
        rpt_vstring(depth, "%.*s%-*s%s", 0, "", 28, "Configuration file options:", default_options);
 
 
-    if (parsed_cmd->output_level >= DDCA_OL_VV)
+    // if (parsed_cmd->output_level >= DDCA_OL_VV)
        report_build_options(depth);
     show_reporting();  // uses fout()
     report_optional_features(parsed_cmd, depth);
@@ -271,66 +276,67 @@ validate_environment()
 }
 
 
-static void verify_i2c_access() {
+int verify_i2c_access() {   // non-static to enable tracing
    bool debug = false;
-   DBGMSF(debug, "Starting");
+   DBGTRC_STARTING(debug, TRACE_GROUP, "");
 
    Bit_Set_256 buses_without_devices = EMPTY_BIT_SET_256;
    Bit_Set_256 inaccessible_devices  = EMPTY_BIT_SET_256;
+   int buses_ct = 0;
+   int buses_without_devices_ct = 0;
+   int inaccessible_devices_ct = 0;
 
    Bit_Set_256 buses = get_possible_ddc_ci_bus_numbers();  //sysfs bus numbers, not dev-i2c
-   DBGMSF(debug, "I2C buses to check: %s", bs256_to_string(buses, "x", " "));
-   if (bs256_count(buses) > 0) {
+   buses_ct = bs256_count(buses);
+   DBGTRC(debug, TRACE_GROUP, "/sys/bus/i2c/devices to check: %s",
+                              bs256_to_string_decimal(buses, "i2c-", ", "));
+   if (buses_ct == 0) {
+      fprintf(stderr, "No /sys/bus/i2c buses that might be used for DDC/CI communication found.\n");
+      fprintf(stderr, "No display adapters with i2c buses appear to exist.\n");
+   }
+   else {
       Bit_Set_256_Iterator iter = bs256_iter_new(buses);
       int busno;
       while ( (busno = bs256_iter_next(iter)) >= 0)  {
          char fnbuf[20];   // oversize to avoid -Wformat-truncation error
          snprintf(fnbuf, sizeof(fnbuf), "/dev/i2c-%d", busno);
-         int rc;
-         int errsv;
-         // DBGMSF(debug, "Calling access() for %s", fnbuf);
-         rc = access(fnbuf, R_OK|W_OK);
-         if (rc < 0) {
-            errsv = errno;   // EACCESS if lack permissions, ENOENT if file doesn't exist
+         if ( access(fnbuf, R_OK|W_OK) < 0 ) {
+            int errsv = errno;   // EACCESS if lack permissions, ENOENT if file doesn't exist
             if (errsv == ENOENT) {
                buses_without_devices = bs256_insert(buses_without_devices, busno);
-               rpt_vstring(0, "Device %s does not exist. Error = %s",
+               fprintf(stderr, "Device %s does not exist. Error = %s\n",
                               fnbuf, linux_errno_desc(errsv));
             }
             else {
-               assert(errsv == EACCES);
                inaccessible_devices = bs256_insert(inaccessible_devices, busno);
-               rpt_vstring(0,"Device %s is not readable and writable.  Error = %s",
+               fprintf(stderr, "Device %s is not readable and writable.  Error = %s\n",
                            fnbuf, linux_errno_desc(errsv) );
                include_open_failures_reported(busno);
             }
          }
       }
       bs256_iter_free(iter);
-   }
+      buses_without_devices_ct = bs256_count(buses_without_devices);
+      inaccessible_devices_ct = bs256_count(inaccessible_devices);
 
-   // DBGMSF(debug, "buses: %d", bs256_count(buses));
-   // DBGMSF(debug, "buses_without_devices: %d", bs256_count(buses_without_devices));
-   // DBGMSF(debug, "inaccessible_devices: %d",  bs256_count(inaccessible_devices));
-   if (bs256_count(buses) == 0) {
-      printf("No display adapters with i2c buses exist.\n");
-      printf("No /sys/bus/i2c buses that might be used for DDC/CI communication exist.\n");
-   }
-   else {
-      if (bs256_count(buses_without_devices) > 0) {
-         printf("/sys/bus/i2c buses without /dev/i2c-N devices: %s\n",
+      if (buses_without_devices_ct > 0) {
+         fprintf(stderr, "/sys/bus/i2c buses without /dev/i2c-N devices: %s\n",
                 bs256_to_string_decimal(buses_without_devices, "/sys/bus/i2c/devices/i2c-", " ") );
-         printf("Driver i2c_dev must be loaded or builtin\n");
-         printf("See https://www.ddcutil.com/kernel_module\n");
+         fprintf(stderr, "Driver i2c_dev must be loaded or builtin\n");
+         fprintf(stderr, "See https://www.ddcutil.com/kernel_module\n");
       }
-      if (bs256_count(inaccessible_devices) > 0) {
-         printf("Devices possibly used for DDC/CCI communication cannot be opened: %s\n",
+      if (inaccessible_devices_ct > 0) {
+         fprintf(stderr, "Devices possibly used for DDC/CI communication cannot be opened: %s\n",
                 bs256_to_string_decimal(inaccessible_devices, "/dev/i2c-", " "));
-         printf("See https://www.ddcutil.com/i2c_permissions\n");
+         fprintf(stderr, "See https://www.ddcutil.com/i2c_permissions\n");
       }
    }
 
-   DBGMSF(debug, "Done");
+   int result = buses_ct - (buses_without_devices_ct + inaccessible_devices_ct);
+   DBGTRC_DONE(debug, TRACE_GROUP,
+         "Returning %d. Total potential buses: %d, buses without devices: %d, inaccessible devices: %d",
+         result, buses_ct, buses_without_devices_ct, inaccessible_devices_ct);
+   return result;
 }
 
 
@@ -444,6 +450,8 @@ find_dref(
                              dref->pedid->mfg_id,
                              dref->pedid->model_name,
                              dref->pedid->product_code);
+            // dref->driver_name = get_i2c_device_sysfs_driver(busno);
+            // DBGMSG("driver_name = %p -> %s", dref->driver_name, dref->driver_name);
 
             // dref->pedid = i2c_get_parsed_edid_by_busno(did_work->busno);
             dref->detail = businfo;
@@ -708,7 +716,7 @@ main(int argc, char *argv[]) {
 #endif
    DBGMSF(main_debug, "apply_config_file() returned %s", psc_desc(apply_config_rc));
    if (config_file_errs->len > 0) {
-      f0printf(ferr(), "Errors processing ddcutil configuration file %s:\n", configure_fn);
+      f0printf(ferr(), "Error(s) reading ddcutil configuration from file %s:\n", configure_fn);
       for (int ndx = 0; ndx < config_file_errs->len; ndx++) {
          char * s = g_strdup_printf("   %s\n", (char *) g_ptr_array_index(config_file_errs, ndx));
          f0printf(ferr(), s);
@@ -748,14 +756,15 @@ main(int argc, char *argv[]) {
    DBGMSF(start_time_reported, "Starting %s execution, %s",
                parser_mode_name(parsed_cmd->parser_mode),
                program_start_time_s);
+#ifdef ENABLE_SYSLOG
    if (trace_to_syslog) {
       openlog("ddcutil",          // prepended to every log message
               LOG_CONS |          // write to system console if error sending to system logger
               LOG_PID,            // include caller's process id
               LOG_USER);          // generic user program, syslogger can use to determine how to handle
       syslog(LOG_INFO, "Starting.  ddcutil version %s", get_full_ddcutil_version());
-
    }
+#endif
 
    bool ok = master_initializer(parsed_cmd);
    if (!ok)
@@ -786,6 +795,7 @@ main(int argc, char *argv[]) {
    }
 
    Call_Options callopts = CALLOPT_NONE;
+   i2c_forceable_slave_addr_flag = parsed_cmd->flags & CMD_FLAG_FORCE_SLAVE_ADDR;
    if (parsed_cmd->flags & CMD_FLAG_FORCE)
       callopts |= CALLOPT_FORCE;
 
@@ -902,7 +912,6 @@ main(int argc, char *argv[]) {
          }  // dref
 
          if (main_rc == EXIT_SUCCESS) {
-
             main_rc = execute_cmd_with_optional_display_handle(parsed_cmd, dh);
          }
 
@@ -938,10 +947,12 @@ bye:
    if (parsed_cmd)
       free_parsed_cmd(parsed_cmd);
    release_base_services();
+#ifdef ENABLE_SYSLOG
    if (trace_to_syslog) {
       syslog(LOG_INFO, "Terminating. Returning %d", main_rc);
       closelog();
    }
+#endif
    return main_rc;
 }
 
@@ -950,6 +961,7 @@ static void add_rtti_functions() {
    RTTI_ADD_FUNC(main);
    RTTI_ADD_FUNC(execute_cmd_with_optional_display_handle);
    RTTI_ADD_FUNC(find_dref);
+      RTTI_ADD_FUNC(verify_i2c_access);
 #ifdef UNUSED
 #ifdef TARGET_LINUX
    RTTI_ADD_FUNC(validate_environment_using_libkmod);
