@@ -3,7 +3,7 @@
  *  Query configuration files, logs, and output of logging commands.
  */
 
-// Copyright (C) 2017-2020 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2017-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 
@@ -16,6 +16,7 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <sys/sysinfo.h>
+#include <syslog.h>
 #include <unistd.h>
 
 #include "util/data_structures.h"
@@ -328,6 +329,8 @@ void probe_logs(Env_Accumulator * accum) {
    // Null_Terminated_String_Array log_terms = all_terms;
    char * rasp_log_terms[] = {
          "i2c",
+         "ddcutil",
+         "ddcui",
          NULL
    };
 
