@@ -2,7 +2,7 @@
  * Functions for creating DDC packets and interpreting DDC response packets.
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -30,7 +30,7 @@
 // Trace control
 //
 
-DDCA_Trace_Group TRACE_GROUP = DDCA_TRC_DDCIO;
+static const DDCA_Trace_Group TRACE_GROUP = DDCA_TRC_DDCIO;
 
 
 //
@@ -70,11 +70,14 @@ Byte xor_bytes(Byte * bytes, int len) {
 #endif
 
 
+/** Calculates the checksum of a DDC message.
+ *  \param  bytes   pointer to bytes of message
+ *  \param  len     length of message
+ *  \param  altmode if true, use x50 as the value of bytes[0],
+ *                  which is the destination address
+ */
 Byte ddc_checksum(Byte * bytes, int len, bool altmode) {
-   // DBGMSG("bytes=%p, len=%d, altmode=%d", bytes, len, altmode);
-   // largest packet is capabilities fragment, which can have up to 32 bytes of text,
-   // plus 4 bytes of offset data.  Adding this to the dest, src, and len bytes is 39
-   // assert(len <= MAX_DDC_PACKET_WO_CHECKSUM);  // no longer needed, not allocating work buffer
+   // DBGMSG("bytes=%p, len=%d, altmode=%s", bytes, len, SBOOL(altmode));
    assert(len >= 1);
 
    Byte checksum = bytes[0];
@@ -83,10 +86,10 @@ Byte ddc_checksum(Byte * bytes, int len, bool altmode) {
    for (int ndx = 1; ndx < len; ndx++) {
       checksum ^= bytes[ndx];
    }
-   // assert(checksum == ddc_checksum_old(bytes, len, altmode));
    return checksum;
 }
 
+
 #ifdef TESTCASES
 void test_one_checksum(Byte * bytes, int len, bool altmode, Byte expected, char * spec_section) {
    unsigned char actual = ddc_checksum(bytes, len, altmode);
@@ -115,6 +118,7 @@ void test_checksum() {
 #endif
 
 
+#ifdef UNUSED
 bool valid_ddc_packet_checksum(Byte * readbuf) {
    bool debug = false;
    bool result = false;
@@ -128,20 +132,25 @@ bool valid_ddc_packet_checksum(Byte * readbuf) {
       readbuf[1] = 0x51;   // dangerous
       unsigned char expected_checksum = ddc_checksum(readbuf, response_size_wo_checksum, false);
       unsigned char actual_checksum   = readbuf[response_size_wo_checksum];
-      DBGMSF(debug, "actual checksum = 0x%02x, expected = 0x%02x",
-                    actual_checksum, expected_checksum);
+      DBGMSF(debug, "data_size=%d, actual checksum = 0x%02x, expected = 0x%02x",
+                    data_size, actual_checksum, expected_checksum);
       result = (expected_checksum == actual_checksum);
    }
 
    DBGMSF(debug, "Returning: %d", result);
    return result;
 }
+#endif
 
 
 //
 //  Packet general functions 
 //
 
+/** Returns a pointer to the raw bytes of a #DDC_Packet.
+ *  \param  pointer to packet
+ *  \return pointer to raw bytes of the packet
+ */
 Byte * get_packet_start(DDC_Packet * packet) {
    Byte * result = NULL;
    if (packet)
@@ -150,57 +159,73 @@ Byte * get_packet_start(DDC_Packet * packet) {
 }
 
 
+/** Returns the total length of the raw bytes of a #DDC_Packet
+ *  \param  pointer to packet
+ *  \param  packet length
+ */
 int get_packet_len(DDC_Packet * packet) {
    return (packet) ? packet->raw_bytes->len : 0;
 }
 
 
+/** Returns the length of the data portion of a #DDC_Packet
+ *  \param  pointer to packet
+ *  \return length of data portion
+ */
 int get_data_len(DDC_Packet * packet) {
    return (packet) ? packet->raw_bytes->len - 4 : 0;
 }
 
 
+/** Returns the start of the data portion of a #DDC_Packet
+ *  \param  pointer to packet
+ *  \return pointer to the data portion
+ */
 Byte * get_data_start(DDC_Packet * packet) {
    return (packet) ? packet->raw_bytes->bytes+3 : NULL;
 }
 
 
+/** Returns the maximum size of the raw bytes buffer in a #DDC_Packet
+ *  \param  pointer to packet
+ *  \return maximum data size
+ */
 int get_packet_max_size(DDC_Packet * packet) {
    return packet->raw_bytes->buffer_size;
 }
 
 
-void dbgrpt_packet(DDC_Packet * packet, int depth) {
-   assert(packet);      // make clang analyzer happy
-   int d0 = depth;
-   // printf("DDC_Packet dump.  Addr: %p, Type: 0x%02x, Tag: |%s|, buf: %p, aux_data: %p\n",
-   //        packet, packet->type, packet->tag, packet->raw_bytes, packet->aux_data);
-   rpt_vstring(depth, "DDC_Packet dump.  Addr: %p, Type: 0x%02x, Tag: |%s|, buf: %p, parsed: %p",
-          packet, packet->type, packet->tag, packet->raw_bytes, packet->parsed.raw_parsed);
-   dbgrpt_buffer(packet->raw_bytes, d0);
-   // TODO show interpreted aux_data
-   if (packet->parsed.raw_parsed) {
-      switch(packet->type) {
-      case (DDC_PACKET_TYPE_CAPABILITIES_RESPONSE):
-      case (DDC_PACKET_TYPE_TABLE_READ_RESPONSE):
-         dbgrpt_interpreted_multi_read_fragment(packet->parsed.multi_part_read_fragment, d0);
-         break;
-      case (DDC_PACKET_TYPE_QUERY_VCP_RESPONSE):
-         dbgrpt_interpreted_nontable_vcp_response(packet->parsed.nontable_response, d0);
-         break;
-      default:
-         // PROGRAM_LOGIC_ERROR("Unexpected packet type: -x%02x", packet->type);
-         rpt_vstring(d0, "PROGRAM_LOGIC_ERROR: Unexpected packet type: -x%02x", packet->type);
-      }
-   }
-}
-
-
+/** Checks if a packet contains a DDC Null Message.
+ *  A null message has 0 length.
+ *  \param  pointer to packet
+ *  \return true if the packet contains a DDC Null Message, false if not
+ *
+ *  Per the DDC/CI spec, Section 6.4 Definition and use of the "Null Message":
+ *
+ *  The NULL message is used in the following cases:
+ *  - To detect that the display is DDC/CI capable (by reading it at the 0x6F slave address)
+ *  - To tell the host that the display does not have any answer to give the host
+ *    (not ready or not expected)
+ *  - The "Enable Application Report" has not been sent before using Application Messages
+ *
+ *  From various NEC monitor manuals:
+ *
+ *  The NULL messages returned from the monitor is used in the following cases:
+ *  - To tell the host that the display does not have any answer to give the host
+ *    (not ready or not expected)
+ *  - Following operations need a certain time for to (sic) execute, so the monitor
+ *    will return this message when another message is received during execution.
+ *    - Power ON, Power OFF, Auto Setup, Input, PIP Input, Auto Setup and Factory reset.
+ */
 bool isNullPacket(DDC_Packet * packet) {
    return  (get_data_len(packet) == 0);
 }
 
 
+/** Frees a #DDC_Packet
+ *
+ *  \param packet pointer to packet to free
+ */
 void free_ddc_packet(DDC_Packet * packet) {
    bool debug = false;
    DBGMSF(debug, "packet=%p", packet);
@@ -209,7 +234,7 @@ void free_ddc_packet(DDC_Packet * packet) {
 
    if (packet) {
       if (packet->parsed.raw_parsed) {
-         DBGMSF(debug, "freeing packet->parsed.raw=%p", packet->parsed.raw_parsed);
+         DBGMSF(debug, "freeing packet->parsed.raw_parsed=%p", packet->parsed.raw_parsed);
          free(packet->parsed.raw_parsed);
       }
 
@@ -277,8 +302,8 @@ create_ddc_base_request_packet(
    assert( data_bytect <= 32 );
 
    DDC_Packet * packet = create_empty_ddc_packet(3+data_bytect+1, tag);
-   buffer_set_byte( packet->raw_bytes, 0, 0x6e);
-   buffer_set_byte( packet->raw_bytes, 1, 0x51);
+   buffer_set_byte( packet->raw_bytes, 0, 0x6e);   // x37<<1 + 0   destination address, write
+   buffer_set_byte( packet->raw_bytes, 1, 0x51);   // x28<<1 + 1   source address
    buffer_set_byte( packet->raw_bytes, 2, data_bytect | 0x80);
    buffer_set_bytes(packet->raw_bytes, 3, data_bytes, data_bytect);
    int packet_size_wo_checksum = 3 + data_bytect;
@@ -430,12 +455,12 @@ create_ddc_multi_part_write_request_packet(
 DDC_Packet *
 create_ddc_getvcp_request_packet(Byte vcp_code, const char * tag)
 {
-   Byte data_bytes[] = { 0x01,     // Command: get VCP Feature
+   Byte data_bytes[] = { DDC_PACKET_TYPE_QUERY_VCP_REQUEST,  // 0x01
                          vcp_code  // VCP opcode
                        };
    DDC_Packet * pkt = create_ddc_base_request_packet(data_bytes, 2, tag);
 
-   // DBGMSG("Done. rc=%d, packet_ptr%p, *packet_ptr=%p", rc, packet_ptr, *packet_ptr);
+   // DBGMSG("Done. rc=%d, packet_ptr=%p, *packet_ptr=%p", rc, packet_ptr, *packet_ptr);
    return pkt;
 }
 
@@ -450,7 +475,7 @@ create_ddc_getvcp_request_packet(Byte vcp_code, const char * tag)
 DDC_Packet *
 create_ddc_setvcp_request_packet(Byte vcp_code, int new_value, const char * tag)
 {
-   Byte data_bytes[] = { 0x03,   // Command: get VCP Feature
+   Byte data_bytes[] = { DDC_PACKET_TYPE_SET_VCP_REQUEST,   // 0x03
                          vcp_code,  // VCP opcode
                          (new_value >> 8) & 0xff,
                          new_value & 0xff
@@ -470,11 +495,11 @@ create_ddc_setvcp_request_packet(Byte vcp_code, int new_value, const char * tag)
 DDC_Packet *
 create_ddc_save_settings_request_packet(const char * tag)
 {
-   Byte data_bytes[] = { 0x0C   // Command: Save Current Settings
+   Byte data_bytes[] = { DDC_PACKET_TYPE_SAVE_CURRENT_SETTINGS   // 0x0C
                        };
    DDC_Packet * pkt = create_ddc_base_request_packet(data_bytes, 1, tag);
 
-   // DBGMSG("Done. rc=%d, packet_ptr%p, *packet_ptr=%p", rc, packet_ptr, *packet_ptr);
+   // DBGMSG("Done. rc=%d, packet_ptr=%p, *packet_ptr=%p", rc, packet_ptr, *packet_ptr);
    return pkt;
 }
 
@@ -490,7 +515,7 @@ create_ddc_save_settings_request_packet(const char * tag)
  *  \param response_bytes_buffer_size  size of buffer pointed to by **i2c_response_bytes**,
  *                                     (used for debug hex dump)
  *  \param tag                         debug string (may be NULL)
- *  \param packet_ptr_addr             where to return pointer to newly allocated #DDC_Packet
+ *  \param packet_ptr_loc              where to return pointer to newly allocated #DDC_Packet
  *
  *  \retval 0
  *  \retval DDCRC_DDC_DATA
@@ -499,14 +524,14 @@ create_ddc_save_settings_request_packet(const char * tag)
  *  \retval DDCRC_PACKET_SIZE         (deprecated)
  *  \retval DDCRC_CHECKSUM            (deprecated)
  *
- *  The pointer returned at packet_ptr_addr is non-null iff the status code is 0.
+ *  The pointer returned at packet_ptr_loc is non-null iff the status code is 0.
  */
 Status_DDC
 create_ddc_base_response_packet(
    Byte *        i2c_response_bytes,
    int           response_bytes_buffer_size,
    const char *  tag,
-   DDC_Packet ** packet_ptr_addr)
+   DDC_Packet ** packet_ptr_loc)
 {
    bool debug = false;
    DBGTRC_STARTING(debug, TRACE_GROUP, "i2c_response_bytes=%p, response_bytes_buffer_size=%d",
@@ -560,12 +585,12 @@ create_ddc_base_response_packet(
    }
 
    if (result == DDCRC_OK)
-      *packet_ptr_addr = packet;
+      *packet_ptr_loc = packet;
    else
-      *packet_ptr_addr = NULL;
+      *packet_ptr_loc = NULL;
 
-   DBGTRC_RETURNING(debug, TRACE_GROUP, result, "*packet_ptr_addr=%p", *packet_ptr_addr);
-   assert( (result==DDCRC_OK && *packet_ptr_addr) || (result != DDCRC_OK && !*packet_ptr_addr));
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, result, "*packet_ptr_loc=%p", *packet_ptr_loc);
+   ASSERT_IFF(result==DDCRC_OK, *packet_ptr_loc);
    return result;
 }
 
@@ -599,12 +624,20 @@ create_ddc_response_packet(
           "response_bytes_buffer_size=%d, i2c_response_bytes=|%s|",
           response_bytes_buffer_size, hexstring_t(i2c_response_bytes, response_bytes_buffer_size));
 
+   if (response_bytes_buffer_size > 2 && i2c_response_bytes[0] == 0x6e
+                                      && i2c_response_bytes[1] == 0x6e) {
+      DDCMSG(debug, "Quirk: response packet starts with double 0x6e");
+      i2c_response_bytes++;
+      response_bytes_buffer_size--;
+   }
+
    Status_DDC result = create_ddc_base_response_packet(
                           i2c_response_bytes,
                           response_bytes_buffer_size,
                           tag,
                           packet_ptr_addr);
-   DBGMSF(debug, "create_ddc_base_response_packet() returned %d, *packet_ptr_addr=%p", result, *packet_ptr_addr);
+   DBGMSF(debug, "create_ddc_base_response_packet() returned %d, *packet_ptr_addr=%p",
+                 result, *packet_ptr_addr);
    if (result == 0) {
       if (isNullPacket(*packet_ptr_addr)) {
          result = DDCRC_NULL_RESPONSE;
@@ -615,8 +648,6 @@ create_ddc_response_packet(
    }
 
    if (result != DDCRC_OK && *packet_ptr_addr) {
-      // if (debug)
-      //    DBGMSG("failure, freeing response packet at %p", *packet_ptr_addr);
       DBGTRC_NOPREFIX(debug, TRACE_GROUP, "failure, freeing response packet at %p", *packet_ptr_addr);
       // does this cause the free(readbuf) failure in try_read?
       free_ddc_packet(*packet_ptr_addr);
@@ -627,7 +658,7 @@ create_ddc_response_packet(
       log_status_code(result, __func__);
    }
 
-   DBGTRC_RETURNING(debug, TRACE_GROUP, result, "*packet_ptr_addr=%p", *packet_ptr_addr);
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, result, "*packet_ptr_addr=%p", *packet_ptr_addr);
    assert( (result==DDCRC_OK && *packet_ptr_addr) || (result != DDCRC_OK && !*packet_ptr_addr));
    return result;
 }
@@ -731,12 +762,12 @@ typedef
 /** Interprets the standard 8 byte VCP feature response.
  *
  * The response is checked for validity, and a
- * Interpreted_Notable_Vcp_Response struct is filled in.
+ * Interpreted_Nontable_Vcp_Response struct is filled in.
  *
  * \param  vcp_data_bytes      pointer to data bytes
  * \param  bytect              number of bytes in response, must be 8
  * \param  requested_vcp_code  must be in the vcp_code field of he response bytes
- * \param  aux_data            pointer to #Parsed_Nontable_Vcp_Response struct to be filled in
+ * \param  parsed_response     pointer to #Parsed_Nontable_Vcp_Response struct to be filled in
  *
  * \retval 0    success
  * \retval DDCRC_DDC_DATA
@@ -747,10 +778,10 @@ typedef
  */
 Status_DDC
 interpret_vcp_feature_response_std(
-       Byte*                 vcp_data_bytes,
-       int                   bytect,
-       Byte                  requested_vcp_code,
-       Parsed_Nontable_Vcp_Response* aux_data)   // record in which interpreted feature response will be stored
+       Byte*                         vcp_data_bytes,
+       int                           bytect,
+       Byte                          requested_vcp_code,
+       Parsed_Nontable_Vcp_Response* parsed_response)   // to be filled in
 {
    bool debug = false;
    DBGTRC_STARTING(debug, TRACE_GROUP,
@@ -759,11 +790,12 @@ interpret_vcp_feature_response_std(
 
    int result = DDCRC_OK;
    // set initial values for failure case:
-   aux_data->vcp_code         = 0x00;
-   aux_data->valid_response   = false;
-   aux_data->supported_opcode = false;
-   aux_data->max_value        = 0;
-   aux_data->cur_value        = 0;
+   memset(parsed_response, 0, sizeof(Parsed_Nontable_Vcp_Response));
+   // parsed_response->vcp_code         = 0x00;
+   // parsed_response->valid_response   = false;
+   // parsed_response->supported_opcode = false;
+   // parsed_response->max_value        = 0;
+   // parsed_response->cur_value        = 0;
 
    if (bytect != 8) {
       DDCMSG(debug, "Invalid response data length: %d, should be 8, response data bytes: %s",
@@ -775,7 +807,7 @@ interpret_vcp_feature_response_std(
       Vcp_Response * vcpresp = (Vcp_Response *) vcp_data_bytes;
       assert( sizeof(*vcpresp) == 8);
       assert(vcpresp->result_code == vcp_data_bytes[1]);  // validate the overlay
-      aux_data->vcp_code = vcpresp->vcp_opcode;
+      parsed_response->vcp_code = vcpresp->vcp_opcode;
       bool valid_response = true;
 
       if (vcpresp->vcp_opcode != requested_vcp_code){
@@ -794,7 +826,7 @@ interpret_vcp_feature_response_std(
                                       "Unsupported VCP Code: 0x%02x", vcpresp->vcp_opcode);
             // if (requested_vcp_code != 0x00 && !msg_emitted)
             //    DDCMSG(debug, "Unsupported VCP Code: 0x%02x", vcpresp->vcp_opcode);
-            aux_data->valid_response = true;
+            parsed_response->valid_response = true;
          }
          else {
             DDCMSG(debug, "Unexpected result code: 0x%02x, response_data_bytes: %s",
@@ -805,28 +837,30 @@ interpret_vcp_feature_response_std(
       }
 
       else {
-         int max_val = (vcpresp->mh << 8) | vcpresp->ml;
-         int cur_val = (vcpresp->sh << 8) | vcpresp->sl;
+         if (debug) {
+            int max_val = (vcpresp->mh << 8) | vcpresp->ml;
+            int cur_val = (vcpresp->sh << 8) | vcpresp->sl;
 
-         DBGTRC_NOPREFIX(debug, TRACE_GROUP,
+            DBGTRC_NOPREFIX(debug, TRACE_GROUP,
                 "vcp_opcode = 0x%02x, vcp_type_code=0x%02x, max_val=%d (0x%04x), cur_val=%d (0x%04x)",
                 vcpresp->vcp_opcode, vcpresp->vcp_typecode, max_val, max_val, cur_val, cur_val);
-         DBGTRC_NOPREFIX(debug, TRACE_GROUP, "valid_response=%s", sbool(valid_response));
+            DBGTRC_NOPREFIX(debug, TRACE_GROUP, "valid_response=%s", sbool(valid_response));
+         }
 
-         aux_data->valid_response   = true;
-         aux_data->supported_opcode = true;
-         aux_data->max_value        = max_val;   // valid only for continuous features
-         aux_data->cur_value        = cur_val;   // valid only for continuous features
+         parsed_response->valid_response   = true;
+         parsed_response->supported_opcode = true;
+         // aux_data->max_value        = max_val;   // valid only for continuous features
+         // aux_data->cur_value        = cur_val;   // valid only for continuous features
          // for new way
-         aux_data->mh = vcpresp->mh;
-         aux_data->ml = vcpresp->ml;
-         aux_data->sh = vcpresp->sh;
-         aux_data->sl = vcpresp->sl;
+         parsed_response->mh = vcpresp->mh;
+         parsed_response->ml = vcpresp->ml;
+         parsed_response->sh = vcpresp->sh;
+         parsed_response->sl = vcpresp->sl;
       }
    }
    
    // result = DDCRC_DDC_DATA; // force error for testing
-   DBGTRC_RETURNING(debug, TRACE_GROUP, result, "");
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, result, "");
    return result;
 }
 
@@ -838,8 +872,8 @@ dbgrpt_interpreted_nontable_vcp_response(
    rpt_vstring(depth,"VCP code:         0x%02x", interpreted->vcp_code);
    rpt_vstring(depth,"valid_response:   %d",     interpreted->valid_response);
    rpt_vstring(depth,"supported_opcode: %d",     interpreted->supported_opcode);
-   rpt_vstring(depth,"max_value:        %d",     interpreted->max_value);
-   rpt_vstring(depth,"cur_value:        %d",     interpreted->cur_value);
+   rpt_vstring(depth,"max_value:        %d",     RESPONSE_MAX_VALUE(interpreted));
+   rpt_vstring(depth,"cur_value:        %d",     RESPONSE_CUR_VALUE(interpreted));
    rpt_vstring(depth,"mh:               0x%02x", interpreted->mh);
    rpt_vstring(depth,"ml:               0x%02x", interpreted->ml);
    rpt_vstring(depth,"sh:               0x%02x", interpreted->sh);
@@ -874,7 +908,7 @@ dbgrpt_parsed_vcp_response(Parsed_Vcp_Response * response, int depth)
  *  \param expected_type               expected packet type
  *  \param expected_subtype            depends on expected_type
  *  \param tag                         debug string (may be NULL)
- *  \param packet_ptr_addr             where to return pointer to newly allocated #DDC_Packet
+ *  \param packet_ptr_loc              where to return pointer to newly allocated #DDC_Packet
  *
  *  \retval 0
  *  \return as from #create_ddc_response_packet()
@@ -892,30 +926,31 @@ create_ddc_typed_response_packet(
       DDC_Packet_Type expected_type,
       Byte            expected_subtype,
       const char*     tag,
-      DDC_Packet**    packet_ptr_addr)
+      DDC_Packet**    packet_ptr_loc)
 {
    bool debug = false;
    DBGTRC_STARTING(debug, TRACE_GROUP, "response_bytes_buffer_size=%d, response_bytes=|%s|",
                               response_bytes_buffer_size, hexstring_t(i2c_response_bytes, response_bytes_buffer_size) );
 
-   // DBGMSG("before create_ddc_response_packet(), *packet_ptr_addr=%p", *packet_ptr_addr);
+   // DBGMSG("before create_ddc_response_packet(), *packet_ptr_addr=%p", *packet_ptr_loc);
    // n. may return DDC_NULL_RESPONSE??   (old note)
    Status_DDC rc = create_ddc_response_packet(
                i2c_response_bytes,
                response_bytes_buffer_size,
                expected_type,
                tag,
-               packet_ptr_addr);
-   DBGTRC_NOPREFIX(debug, TRACE_GROUP, "Create_ddc_response_packet() returned %s, *packet_ptr_addr=%p",
-                               psc_desc(rc), *packet_ptr_addr);
+               packet_ptr_loc);
+   DBGTRC_NOPREFIX(debug, TRACE_GROUP, "Create_ddc_response_packet() returned %s, *packet_ptr_loc=%p",
+                               psc_desc(rc), *packet_ptr_loc);
    if (rc == 0) {
-      DDC_Packet * packet = *packet_ptr_addr;
+      DDC_Packet * packet = *packet_ptr_loc;
       switch (expected_type) {
 
       case DDC_PACKET_TYPE_CAPABILITIES_RESPONSE:
       case DDC_PACKET_TYPE_TABLE_READ_RESPONSE:
          {
-            Interpreted_Multi_Part_Read_Fragment * aux_data = calloc(1, sizeof(Interpreted_Multi_Part_Read_Fragment));
+            Interpreted_Multi_Part_Read_Fragment * aux_data
+                  = calloc(1, sizeof(Interpreted_Multi_Part_Read_Fragment));
             packet->parsed.multi_part_read_fragment = aux_data;
             rc = interpret_multi_part_read_response(
                    expected_type,
@@ -927,7 +962,8 @@ create_ddc_typed_response_packet(
 
       case DDC_PACKET_TYPE_QUERY_VCP_RESPONSE:
          {
-            Parsed_Nontable_Vcp_Response * aux_data = calloc(1, sizeof(Parsed_Nontable_Vcp_Response));
+            Parsed_Nontable_Vcp_Response * aux_data
+                  = calloc(1, sizeof(Parsed_Nontable_Vcp_Response));
             packet->parsed.nontable_response = aux_data;
             rc = interpret_vcp_feature_response_std(
                     get_data_start(packet),
@@ -944,16 +980,16 @@ create_ddc_typed_response_packet(
       }
    }
 
-   if (rc != DDCRC_OK && *packet_ptr_addr) {
-      free_ddc_packet(*packet_ptr_addr);
-      *packet_ptr_addr = NULL;
+   if (rc != DDCRC_OK && *packet_ptr_loc) {
+      free_ddc_packet(*packet_ptr_loc);
+      *packet_ptr_loc = NULL;
    }
 
-   DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "*packet_ptr=%p", *packet_ptr_addr);
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "*packet_ptr_loc=%p", *packet_ptr_loc);
    if ( (debug || IS_TRACING()) && rc >= 0)
-      dbgrpt_packet(*packet_ptr_addr, 2);
+      dbgrpt_packet(*packet_ptr_loc, 2);
 
-   assert( (rc == 0 && *packet_ptr_addr) || (rc != 0 && !*packet_ptr_addr));
+   ASSERT_IFF(rc == 0, *packet_ptr_loc);
    return rc;
 }
 
@@ -1008,11 +1044,12 @@ create_ddc_multi_part_read_response_packet(
    }
    if (rc == 0)
       *packet_ptr = packet;
-   DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "*packet_ptr=%p", *packet_ptr);
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "*packet_ptr=%p", *packet_ptr);
    return rc;
 }
 #endif
 
+
 // VCP Feature response
 
 // 4/2017: used only in ddc_vcp_tests.c:
@@ -1067,7 +1104,7 @@ create_ddc_getvcp_response_packet(
    }
    if (rc == 0)
       *packet_ptr = packet;
-   DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "*packet_ptr=%p", *packet_ptr);
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "*packet_ptr=%p", *packet_ptr);
    return rc;
 }
 
@@ -1076,22 +1113,19 @@ create_ddc_getvcp_response_packet(
 // Operations on response packets
 // 
 
-
 // VCP Feature Code
 
 /** Extracts the interpretation of a non-table VCP response from a #DDC_Packet.
  *
- *  This is the aux_data field of #DDC_Packet
- *
- * \param   packet      pointer to digested packet (not raw bytes)
+ * \param   packet     pointer to digested packet (not raw bytes)
  * \param   make_copy  if true, make a copy of the aux_data field,\n
  *                     if false, just return a pointer to it
- * \param   interpreted_loc  where to return pointer to newly allocated #Parsed_Nontable_Vcp_Response
- * \retval  0    success
+ * \param   interpreted_loc  where to return pointer to #Parsed_Nontable_Vcp_Response
+ * \retval  0                    success
  * \retval  DDCRC_RESPONSE_TYPE  not a VCP response packet  (deprecated)
  * \retval  DDCRC_DDC_DATA       not a VCP response packet
  *
- * The value pointed to by **interpreted_ptr** is non-null iff the returned status code is 0.
+ * The value pointed to by **interpreted_loc** is non-null iff the returned status code is 0.
  */
 Status_DDC
 get_interpreted_vcp_code(
@@ -1118,26 +1152,59 @@ get_interpreted_vcp_code(
       }
    }
    DBGMSF(debug, "Returning %d: %s\n", rc, psc_desc(rc) );
-   assert( (rc == 0 && *interpreted_loc) || (rc && !*interpreted_loc));
+   ASSERT_IFF(rc == 0, *interpreted_loc);
    return rc;
 }
 
 
+/** Emits a debug report of a #DDC_Packet
+ *  \param  packet  pointer to packet
+ *  \param  depth   logical indentation depth
+ */
+void dbgrpt_packet(DDC_Packet * packet, int depth) {
+   assert(packet);      // make clang analyzer happy
+   int d0 = depth;
+   // printf("DDC_Packet dump.  Addr: %p, Type: 0x%02x, Tag: |%s|, buf: %p, aux_data: %p\n",
+   //        packet, packet->type, packet->tag, packet->raw_bytes, packet->aux_data);
+   rpt_vstring(depth, "DDC_Packet dump.  Addr: %p, Type: 0x%02x, Tag: |%s|, buf: %p, parsed: %p",
+          packet, packet->type, packet->tag, packet->raw_bytes, packet->parsed.raw_parsed);
+   dbgrpt_buffer(packet->raw_bytes, d0);
+   // TODO show interpreted aux_data
+   if (packet->parsed.raw_parsed) {
+      switch(packet->type) {
+      case (DDC_PACKET_TYPE_CAPABILITIES_RESPONSE):
+      case (DDC_PACKET_TYPE_TABLE_READ_RESPONSE):
+         dbgrpt_interpreted_multi_read_fragment(packet->parsed.multi_part_read_fragment, d0);
+         break;
+      case (DDC_PACKET_TYPE_QUERY_VCP_RESPONSE):
+         dbgrpt_interpreted_nontable_vcp_response(packet->parsed.nontable_response, d0);
+         break;
+      default:
+         // PROGRAM_LOGIC_ERROR("Unexpected packet type: -x%02x", packet->type);
+         rpt_vstring(d0, "PROGRAM_LOGIC_ERROR: Unexpected packet type: -x%02x", packet->type);
+      }
+   }
+}
+
+
+#ifdef UNUSED
 // 12/23/2015: not currently used
 Status_DDC get_vcp_cur_value(DDC_Packet * packet, int * value_ptr) {
    Parsed_Nontable_Vcp_Response * aux_ptr;
    Status_DDC rc = get_interpreted_vcp_code(packet, false, &aux_ptr);
    if (rc == 0) {
-      *value_ptr = aux_ptr->cur_value;
+      // *value_ptr = aux_ptr->sh<<8 | aux_ptr->sl;  // aux_ptr->cur_value;
+      *value_ptr = RESPONSE_CUR_VALUE(aux_ptr);
    }
    return rc;
 }
+#endif
 
 
 void init_ddc_packets() {
    RTTI_ADD_FUNC(create_ddc_base_response_packet);
    RTTI_ADD_FUNC(create_ddc_getvcp_response_packet);
-// RTTI_ADD_FUNC(create_ddc_multi_part_read_response_packet);
+// RTTI_ADD_FUNC(create_ddc_multi_part_read_response_packet);  // unused
    RTTI_ADD_FUNC(create_ddc_response_packet);
    RTTI_ADD_FUNC(create_ddc_typed_response_packet);
    RTTI_ADD_FUNC(interpret_vcp_feature_response_std);
