@@ -2,7 +2,7 @@
  * Functions for creating DDC packets and interpreting DDC response packets.
  */
 
-// Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef DDC_PACKETS_H_
@@ -19,8 +19,10 @@
 #include "base/status_code_mgt.h"
 #include "base/core.h"
 
+#ifdef UNUSED
 // was in common.h
 #define MAX_DDCCI_PACKET_SIZE   37    //  32 + 5;
+#endif
 
 // largest packet is capabilities response packet, which has 1 byte for reply op code,
 // 2 for offset, and up to 32 bytes fragment
@@ -54,16 +56,16 @@ typedef
 struct {
    Byte   vcp_code;             ///< VCP feature code
    bool   valid_response;       ///<
-   bool   supported_opcode;
-   int    max_value;
-   int    cur_value;
-   // for new way
-   Byte   mh;
-   Byte   ml;
-   Byte   sh;
-   Byte   sl;
+   bool   supported_opcode;     ///< is opcode supported?
+   Byte   mh;                   ///< max value high order byte
+   Byte   ml;                   ///< max value low  order byte
+   Byte   sh;                   ///< current value high order byte
+   Byte   sl;                   ///< current value low  order byte
 } Parsed_Nontable_Vcp_Response;
 
+#define HI_LO_BYTES_TO_SHORT(hi,lo) ( (hi)<<8 | (lo))
+#define RESPONSE_CUR_VALUE(response) (response->sh<<8 | response->sl)
+#define RESPONSE_MAX_VALUE(response) (response->mh<<8 | response->ml)
 
 static inline bool
 value_bytes_zero(Parsed_Nontable_Vcp_Response * parsed_val) {
@@ -85,7 +87,7 @@ struct {
 } Interpreted_Multi_Part_Read_Fragment;
 
 
-// TODO: Unify with list in ddc_command_codes.h
+// Keep in sync with list in ddc_command_codes.h
 typedef Byte DDC_Packet_Type;
 #define DDC_PACKET_TYPE_NONE                  0x00
 #define DDC_PACKET_TYPE_QUERY_VCP_REQUEST     0x01
@@ -103,12 +105,9 @@ typedef Byte DDC_Packet_Type;
 /** Packet bytes and interpretation */
 typedef
 struct {
-   Buffer *         raw_bytes;                ///< raw packet bytes
-   char             tag[MAX_DDC_TAG+1]; ///* debug string describing packet, +1 for \0
-   DDC_Packet_Type  type;               ///* packet type
-   // void *           aux_data;           ///* type dependent
-
-   // for a bit more type safety and code clarity:
+   Buffer *         raw_bytes;          ///< raw packet bytes
+   char             tag[MAX_DDC_TAG+1]; ///< debug string describing packet, +1 for \0
+   DDC_Packet_Type  type;               ///< packet type
    union {
       Parsed_Nontable_Vcp_Response *         nontable_response;
       Interpreted_Multi_Part_Read_Fragment * multi_part_read_fragment;
@@ -126,7 +125,9 @@ bool is_double_byte(Byte * pb);
 
 // Byte xor_bytes(Byte * bytes, int len);
 Byte ddc_checksum(Byte * bytes, int len, bool altmode);
+#ifdef UNUSED
 bool valid_ddc_packet_checksum(Byte * readbuf);
+#endif
 // void test_checksum();
 
 
@@ -233,10 +234,12 @@ void
 dbgrpt_interpreted_multi_read_fragment(
       Interpreted_Multi_Part_Read_Fragment * interpreted,
       int depth);
+
 void
 dbgrpt_interpreted_nontable_vcp_response(
       Parsed_Nontable_Vcp_Response * interpreted,
       int depth);
+
 #ifdef OLD
 void   report_interpreted_aux_data(Byte response_type, void * interpreted);
 #endif
