@@ -2,7 +2,7 @@
  *  Record execution statistics, mainly the count and elapsed time of system calls.
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -71,7 +71,6 @@ static Status_Code_Counts * retryable_error_code_counts;
 static GMutex               status_code_counts_mutex;
 static GMutex               global_stats_mutex;
 
-
 static bool                 debug_status_code_counts_mutex  = false;
 static bool                 debug_global_stats_mutex = false;
 static bool                 debug_sleep_stats_mutex = false;
@@ -83,20 +82,20 @@ static bool                 debug_sleep_stats_mutex = false;
 
 static
 IO_Event_Type_Stats io_event_stats[] = {
-      // id           name             desc           nanosec  count
-      {IE_WRITE,      "IE_WRITE",      "write calls",            0, 0},
-      {IE_READ,       "IE_READ",       "read calls",             0, 0},
-      {IE_IOCTL_WRITE,"I2_IOCTL_WRITE","i2c writes using ioctl", 0, 0},
-      {IE_IOCTL_READ, "I2_IOCTL_READ", "i2c reads using ioctl",  0, 0},
-//    {IE_WRITE_READ, "IE_WRITE_READ", "write/read calls",       0, 0},
-      {IE_OPEN,       "IE_OPEN",       "open file calls",        0, 0},
-      {IE_CLOSE,      "IE_CLOSE",      "close file calls",       0, 0},
-      {IE_OTHER,      "IE_OTHER",      "other I/O calls",        0, 0},
+   // id             name               desc                  nanosec  count
+   {IE_FILEIO_WRITE, "IE_FILEIO_WRITE", "i2c writes using write()", 0, 0},
+   {IE_FILEIO_READ,  "IE_FILEIO_READ",  "i2c reads using read()",   0, 0},
+   {IE_IOCTL_WRITE,  "I2_IOCTL_WRITE",  "i2c writes using ioctl",   0, 0},
+   {IE_IOCTL_READ,   "I2_IOCTL_READ",   "i2c reads using ioctl",    0, 0},
+   {IE_OPEN,         "IE_OPEN",         "open file calls",          0, 0},
+   {IE_CLOSE,        "IE_CLOSE",        "close file calls",         0, 0},
+   {IE_OTHER,        "IE_OTHER",        "other I/O calls",          0, 0},
 };
 #define IO_EVENT_TYPE_CT (sizeof(io_event_stats)/sizeof(IO_Event_Type_Stats))
 static GMutex io_event_stats_mutex;
 static bool   debug_io_event_stats_mutex;
 
+
 static
 void reset_io_event_stats() {
    bool debug = false || debug_io_event_stats_mutex;
@@ -119,7 +118,6 @@ void reset_io_event_stats() {
  * @return symbolic name
  */
 const char * io_event_name(IO_Event_Type event_type) {
-   // return io_event_names[event_type];
    return io_event_stats[event_type].name;
 }
 
@@ -146,7 +144,8 @@ static int total_io_event_count() {
    return total;
 }
 
-// unused
+
+#ifdef UNUSED
 uint64_t total_io_event_nanosec() {
    uint64_t total = 0;
    int ndx = 0;
@@ -154,6 +153,7 @@ uint64_t total_io_event_nanosec() {
       total += io_event_stats[ndx].call_nanosec;
    return total;
 }
+#endif
 
 
 // No effect on program logic, but makes debug messages easier to scan
@@ -165,7 +165,7 @@ uint64_t normalize_timestamp(uint64_t timestamp) {
 /** Called immediately after an I2C IO call, this function updates the total
  *  number of calls and elapsed time for categories of calls.
  *
- *  @param  event_type        e.g. IE_WRITE
+ *  @param  event_type        e.g. IE_IOCTL_WRITE
  *  @param  location          function name
  *  @param  start_time_nanos  starting time of the event in nanoseconds
  *  @param  end_time_nanos    ending time of the event in nanoseconds
@@ -237,23 +237,20 @@ typedef struct {
    uint64_t nanos;
 } Non_Sleep_Call_Totals;
 
+
 Non_Sleep_Call_Totals
 get_non_sleep_call_totals () {
    Non_Sleep_Call_Totals totals;
    totals.count = 0;
    totals.nanos = 0;
-    int ndx = 0;
-    // int max_name_length = max_event_name_length();
-
-    for (;ndx < IO_EVENT_TYPE_CT; ndx++) {
-       if (io_event_stats[ndx].call_count > 0) {
-          IO_Event_Type_Stats* curstat = &io_event_stats[ndx];
-
-          totals.count += curstat->call_count;
-          totals.nanos += curstat->call_nanosec;
-       }
-    }
-    return totals;
+   for (int ndx = 0; ndx < IO_EVENT_TYPE_CT; ndx++) {
+      if (io_event_stats[ndx].call_count > 0) {
+         IO_Event_Type_Stats* curstat = &io_event_stats[ndx];
+         totals.count += curstat->call_count;
+         totals.nanos += curstat->call_nanosec;
+      }
+   }
+   return totals;
  }
 
 
@@ -285,6 +282,7 @@ Status_Code_Counts * new_status_code_counts(char * name) {
    return pcounts;
 }
 
+
 static void
 reset_status_code_counts_struct(Status_Code_Counts * pcounts) {
    bool debug = false || debug_status_code_counts_mutex;
@@ -301,7 +299,6 @@ reset_status_code_counts_struct(Status_Code_Counts * pcounts) {
 }
 
 
-
 static void
 reset_status_code_counts() {
    reset_status_code_counts_struct(primary_error_code_counts);
@@ -309,7 +306,6 @@ reset_status_code_counts() {
 }
 
 
-
 static
 int log_any_status_code(Status_Code_Counts * pcounts, int rc, const char * caller_name) {
    bool debug = false || debug_status_code_counts_mutex;
@@ -361,6 +357,7 @@ log_status_code(Public_Status_Code rc, const char * caller_name) {
    return rc;
 }
 
+
 /** Log a status code that occurs in a retry loop
  *
  * @param rc           status code
@@ -453,6 +450,8 @@ void report_specific_status_counts(Status_Code_Counts * pcounts, int depth) {
 
 
 /** Master function to display status counts
+ *
+ *  @param depth logical_indentation_depth
  */
 void report_all_status_counts(int depth) {
    report_specific_status_counts(primary_error_code_counts, 0);
@@ -497,23 +496,20 @@ int get_true_io_error_count(Status_Code_Counts * pcounts) {
 // Sleep Strategy
 //
 
-
 // Names for Sleep_Event enum values
 static const char * sleep_event_names[] = {
       "SE_WRITE_TO_READ",
       "SE_POST_WRITE",
       "SE_POST_READ",
-      "SE_DDC_NULL",
       "SE_POST_SAVE_SETTINGS",
       "SE_PRE_MULTI_PART_READ",
-      "SE_MULTI_PART_READ_TO_WRITE",
-      "SE_BETWEEN_CAP_TABLE_SEGMENTS",
-      "SE_POST_CAP_TABLE_COMMAND",
+      "SE_POST_CAP_TABLE_SEGMENT",
       "SE_SPECIAL",
      };
 #define SLEEP_EVENT_ID_CT (sizeof(sleep_event_names)/sizeof(char *))
 
-int max_sleep_event_name_size() {
+static int
+max_sleep_event_name_size() {
    int result = 0;
    for (int ndx = 0; ndx < SLEEP_EVENT_ID_CT; ndx++) {
       if (strlen(sleep_event_names[ndx]) > result)
@@ -522,7 +518,11 @@ int max_sleep_event_name_size() {
    return result;
 }
 
-/** Returns the name of sleep event type */
+/** Returns the name of a sleep event type
+ *
+ *  @param event_type sleep event type, e.g. SE_WRITE_TO_READ
+ *  @result
+ * */
 const char * sleep_event_name(Sleep_Event_Type event_type) {
    // ensure sleep_event_names stays in sync with Sync_Event_Type
 #ifndef NDEBUG
@@ -532,9 +532,8 @@ const char * sleep_event_name(Sleep_Event_Type event_type) {
    return sleep_event_names[event_type];
 }
 
-static int sleep_event_cts_by_id[SLEEP_EVENT_ID_CT];
-static int total_sleep_event_ct = 0;
-
+static int    sleep_event_cts_by_id[SLEEP_EVENT_ID_CT];
+static int    total_sleep_event_ct = 0;
 static GMutex sleep_stats_mutex;
 
 
@@ -551,6 +550,7 @@ void reset_sleep_event_counts() {
    DBGMSF(debug, "Done");
 }
 
+
 void record_sleep_event(Sleep_Event_Type event_type) {
    // For better performance, separate mutex for each index in array
    g_mutex_lock(&sleep_stats_mutex);
