@@ -1,9 +1,9 @@
-/** \file monitor_model_key.h
+/** @file monitor_model_key.h
  *  Uniquely identifies a monitor model using its manufacturer id,
  *  model name, and product code, as listed in the EDID.
  */
 
-// Copyright (C) 2018-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2018-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef MONITOR_MODEL_KEY_H_
@@ -11,8 +11,11 @@
 
 #include <inttypes.h>
 
+#include "public/ddcutil_types.h"
 #include "private/ddcutil_types_private.h"
 
+#include "util/edid.h"
+
 DDCA_Monitor_Model_Key
 monitor_model_key_value(
       const char *   mfg_id,
@@ -22,6 +25,9 @@ monitor_model_key_value(
 DDCA_Monitor_Model_Key
 monitor_model_key_undefined_value();
 
+DDCA_Monitor_Model_Key
+monitor_model_key_value_from_edid(Parsed_Edid * edid);
+
 DDCA_Monitor_Model_Key *
 monitor_model_key_new(
       const char *   mfg_id,
