@@ -1,4 +1,4 @@
-/** \file parms.h
+/** @file parms.h
  *
  *  System configuration and tuning
  */
@@ -15,35 +15,32 @@
 
 // n. the DDC spec lists timeout values in milliseconds
 
-#define DDC_TIMEOUT_MILLIS_DEFAULT                   50  ///< Normal timeout in DDC spec
-
-#define DDC_TIMEOUT_MILLIS_BETWEEN_GETVCP_WRITE_READ 40   ///< Between DDC Get Feature Request and Get Feature Reply
-#define DDC_TIMEOUT_MILLIS_POST_SETVCP_WRITE         50   ///< Following DDC Set VCP Feature command
-#define DDC_TIMEOUT_MILLIS_POST_SAVE_SETTINGS              200   ///< Following DDC Save Settings
-#define DDC_TIMEOUT_MILLIS_POST_NORMAL_COMMAND              50   ///< spec ambiguous
-#define DDC_TIMEOUT_MILLIS_BETWEEN_CAP_TABLE_FRAGMENTS      50
-#define DDC_TIMEOUT_MILLIS_POST_CAP_TABLE_COMMAND           50   ///< needed? spec ambiguous
-
-#ifdef UNUSED
-#define DDC_TIMEOUT_MILLIS_POST_CAPABILITIES_READ    50
-#endif
+#define DDC_TIMEOUT_MILLIS_DEFAULT                      50  ///< Normal timeout in DDC spec
+#define DDC_TIMEOUT_MILLIS_BETWEEN_GETVCP_WRITE_READ    40   ///< Between DDC Get Feature Request and Get Feature Reply
+#define DDC_TIMEOUT_MILLIS_POST_SETVCP_WRITE            50   ///< Following DDC Set VCP Feature command
+#define DDC_TIMEOUT_MILLIS_POST_SAVE_SETTINGS          200   ///< Following DDC Save Settings
+#define DDC_TIMEOUT_MILLIS_BETWEEN_CAP_TABLE_FRAGMENTS  50
+#define DDC_TIMEOUT_MILLIS_POST_CAP_TABLE_COMMAND       50   ///< needed? spec ambiguous
 
 // Timeouts not part of DDC spec
-#define DDC_TIMEOUT_MILLIS_RETRY                    200  ///< Between retries
-#define DDC_TIMEOUT_USE_DEFAULT                      -1  ///< Use the default timeout
-#define DDC_TIMEOUT_NONE                              0  ///< No timeout
-#define DDC_TIMEOUT_MILLIS_NULL_RESPONSE_INCREMENT  100  ///< Used for dynamic tuned sleep in case of DDC Null Message response
+#define DDC_TIMEOUT_NONE                                 0  ///< No timeout
+#define DDC_TIMEOUT_MILLIS_NULL_RESPONSE_INCREMENT     100  ///< Used for dynamic tuned sleep in case of DDC Null Message response
 
 
 //
-// *** Choose method of low level IC2 communication
+// *** Method of low level I2C communication
 //
 
-#define DEFAULT_DDC_READ_BYTEWISE      false                   ///< Use single byte reads
-#define DEFAULT_EDID_WRITE_BEFORE_READ true
-#define DEFAULT_EDID_READ_SIZE           0                     ///< 128, 256, 0=>dynamic
-#define EDID_BUFFER_SIZE               256                     ///< always 256
+// One of the following 2 defines must be enabled:
+#define DEFAULT_I2C_IO_STRATEGY           I2C_IO_STRATEGY_IOCTL ///< Use ioctl() calls
+// #define DEFAULT_I2C_IO_STRATEGY           I2C_IO_STRATEGY_FILEIO  ///< Use read() and write()
 
+#define DEFAULT_DDC_READ_BYTEWISE         false       ///< Use single byte reads
+
+#define EDID_BUFFER_SIZE                  256         ///< always 256
+#define DEFAULT_EDID_WRITE_BEFORE_READ    true
+#define DEFAULT_EDID_READ_SIZE            0           ///< 128, 256, 0=>dynamic
+#define DEFAULT_EDID_READ_USES_I2C_LAYER  true
 #define DEFAULT_EDID_READ_BYTEWISE        false
 
 // Strategy    Bytewise    read edid uses local i2c call                      read edid uses i2c layer
@@ -97,5 +94,4 @@
 #define DEFAULT_ENABLE_CACHED_CAPABILITIES true
 #define DEFAULT_ENABLE_UDF true
 
-
 #endif /* PARMS_H_ */
