@@ -2,12 +2,11 @@
  *
  *  Status Code Management
  */
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
 #include <assert.h>
-#include <base/adl_errors.h>
 #include <glib-2.0/glib.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -19,9 +18,7 @@
 
 #include "base/status_code_mgt.h"
 
-
 /*
-
 Notes on status code management.
 
 Status codes in the ddcutil have multiple sources:
@@ -262,7 +259,7 @@ Status_Code_Info * find_status_code_info(Public_Status_Code status_code) {
       pinfo = finder_func(rawrc);
    }
    if (debug) {
-      printf("(%s) Done.  Returning %p\n", __func__, pinfo);
+      printf("(%s) Done.  Returning %p\n", __func__, (void*)pinfo);
       if (pinfo)
          report_status_code_info(pinfo);
    }
@@ -274,6 +271,7 @@ Status_Code_Info * find_status_code_info(Public_Status_Code status_code) {
 #define GSC_WORKBUF_SIZE 300
 
 /** Returns a description string for a #Public_Status_Code.
+ *  Normally this has the form: symbolic-name(numeric-value): description
  *  Synthesizes a description if information for the status code cannot be found.
  *
  *  @param  psc  status code number
@@ -286,9 +284,6 @@ Status_Code_Info * find_status_code_info(Public_Status_Code status_code) {
 char * psc_desc(Public_Status_Code psc) {
    static GPrivate  psc_desc_key = G_PRIVATE_INIT(g_free);
    char * workbuf = get_thread_fixed_buffer(&psc_desc_key, GSC_WORKBUF_SIZE);
-   // printf("(%s) workbuf=%p\n", __func__, workbuf);
-   // static char workbuf[GSC_WORKBUF_SIZE];
-   // printf("(%s) status_code=%d\n", __func__, status_code);
    Status_Code_Info * pinfo = find_status_code_info(psc);
    if (pinfo) {
       snprintf(workbuf, GSC_WORKBUF_SIZE, "%s(%d): %s",
@@ -302,7 +297,7 @@ char * psc_desc(Public_Status_Code psc) {
 }
 
 
-/** Returns a string containing the name of a #Public_Status_Code,
+/** Returns a string containing the symbolic name of a #Public_Status_Code,
  *  followed by its numeric value.
  *
  *  If the code is not recognized, the string contains only the numeric value.
@@ -317,23 +312,16 @@ char * psc_desc(Public_Status_Code psc) {
 char * psc_name_code(Public_Status_Code psc) {
    static GPrivate  psc_desc_key = G_PRIVATE_INIT(g_free);
    char * workbuf = get_thread_fixed_buffer(&psc_desc_key, GSC_WORKBUF_SIZE);
-   // printf("(%s) workbuf=%p\n", __func__, workbuf);
-   // static char workbuf[GSC_WORKBUF_SIZE];
-   // printf("(%s) status_code=%d\n", __func__, status_code);
    Status_Code_Info * pinfo = find_status_code_info(psc);
    if (pinfo) {
-      snprintf(workbuf, GSC_WORKBUF_SIZE, "%s(%d)",
-               pinfo->name, psc);
+      snprintf(workbuf, GSC_WORKBUF_SIZE, "%s(%d)", pinfo->name, psc);
    }
    else {
-      snprintf(workbuf, GSC_WORKBUF_SIZE, "%d",
-               psc );
+      snprintf(workbuf, GSC_WORKBUF_SIZE, "%d", psc);
    }
    return workbuf;
 }
 
-
-
 #undef GSC_WORKBUF_SIZE
 
 
@@ -366,7 +354,6 @@ bool status_name_to_unmodulated_number(
    bool found = false;
 
    for (int ndx = 1; ndx < retcode_range_ct; ndx++) {
-      // printf("ndx=%d, id=%d, base=%d\n", ndx, retcode_range_table[ndx].id, retcode_range_table[ndx].base);
       if (retcode_range_table[ndx].base_number_finder) {
          found = retcode_range_table[ndx].base_number_finder(status_code_name, &status_code);
          if (found)
@@ -395,7 +382,6 @@ status_name_to_modulated_number(
    bool found = false;
 
    for (int ndx = 1; ndx < retcode_range_ct; ndx++) {
-      // printf("ndx=%d, id=%d, base=%d\n", ndx, retcode_range_table[ndx].id, retcode_range_table[ndx].base);
       if (retcode_range_table[ndx].number_finder) {
          found = retcode_range_table[ndx].number_finder(status_code_name, &psc);
          if (found)
@@ -416,10 +402,8 @@ status_name_to_modulated_number(
  */
 void init_status_code_mgt() {
    // N.B called before command line parsed, so command line trace control not in effect
-   // printf("(%s) Starting\n", __func__);
    validate_retcode_range_table();                         // uses asserts to check consistency
    // error_counts_hash = g_hash_table_new(NULL,NULL);
-
    // initialize_ddcrc_desc();
 }
 
@@ -430,7 +414,7 @@ void init_status_code_mgt() {
  * @param pdesc  pointer to #Status_Code_Info struct
  */
 void report_status_code_info(Status_Code_Info * pdesc) {
-   printf("Status_Code_Info struct at %p\n", pdesc);
+   printf("Status_Code_Info struct at %p\n", (void*)pdesc);
    if (pdesc) {
       printf("code:                 %d\n",     pdesc->code);
       printf("name:                 %p: %s\n", pdesc->name, pdesc->name);
