@@ -15,6 +15,7 @@
 #include "base/core.h"
 #include "base/dynamic_sleep.h"
 #include "base/execution_stats.h"
+#include "base/per_thread_data.h"
 #include "base/rtti.h"
 #include "base/sleep.h"
 #include "base/thread_sleep_data.h"
@@ -35,6 +36,7 @@ static DDCA_Trace_Group TRACE_GROUP = DDCA_TRC_SLEEP;
 //
 
 static bool deferred_sleep_enabled = false;
+bool suppress_se_post_read = false;
 
 
 /** Enables or disables deferred sleep.
@@ -65,7 +67,7 @@ bool is_deferred_sleep_enabled() {
  *  @param is_deferrable_loc where to return flag indicating whether the sleep
  *                           can be deferred or must be performed immiediately
  */
-int get_sleep_time(
+static int get_sleep_time(
       Sleep_Event_Type event_type,
       int              special_sleep_time_millis,
       bool*            is_deferrable_loc)
@@ -86,20 +88,28 @@ int get_sleep_time(
       //     and preparation of the reply message by the display
       // 4.6 Capabilities Request & Reply:
       //     write to read interval unclear, assume 50 ms
-      //  Use 50 ms for both
+      // Note: ddc_i2c_write_read_raw() is used for both normal VCP feature reads
+      // and reads within a capabilities or table command.  It can't distinguish a
+      // normal write/read from one inside a multi part read.  So this sleep time
+      // is used for both.
       //  spec_sleep_time_millis = DDC_TIMEOUT_MILLIS_BETWEEN_GETVCP_WRITE_READ;
       spec_sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
+      // spec_sleep_time_millis = 0; // *** TEMP ***
       deferrable_sleep = deferred_sleep_enabled;
       break;
    case SE_POST_WRITE: // post SET VCP FEATURE write, between SET TABLE write fragments, after final?
       // 4.4 Set VCP Feature:
       //   The host should wait at least 50ms to ensure next message is received by the display
-      spec_sleep_time_millis = DDC_TIMEOUT_MILLIS_POST_NORMAL_COMMAND;
+      spec_sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
       deferrable_sleep = deferred_sleep_enabled;
       break;
    case SE_POST_READ:
       deferrable_sleep = deferred_sleep_enabled;
-      spec_sleep_time_millis = DDC_TIMEOUT_MILLIS_POST_NORMAL_COMMAND;
+      spec_sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
+      if (suppress_se_post_read) {
+         DBGMSG("Suppressing SE_POST_READ");
+         spec_sleep_time_millis = 0;
+      }
       break;
    case SE_POST_SAVE_SETTINGS:
       // 4.5 Save Current Settings:
@@ -107,15 +117,11 @@ int get_sleep_time(
       deferrable_sleep = deferred_sleep_enabled;
       spec_sleep_time_millis = DDC_TIMEOUT_MILLIS_POST_SAVE_SETTINGS; // per DDC spec
       break;
-   case SE_MULTI_PART_WRITE_TO_READ:
-      // Not defined in spec for capabilities or table read. Assume 50 ms.
-      //
-      // Note: This constant is not used.  ddc_i2c_write_read_raw() can't distinguish a normal write/read
-      // from one inside a multi part read, and always uses SE_WRITE_TO_READ.
-      // Address this by using 50 ms for SE_WRITE_TO_READ.
-      spec_sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
+   case SE_PRE_MULTI_PART_READ:
+      // before reading capabilities - this is based on testing, not defined in spec
+      spec_sleep_time_millis = 200;
       break;
-   case SE_AFTER_EACH_CAP_TABLE_SEGMENT:
+   case SE_POST_CAP_TABLE_SEGMENT:
       // 4.6 Capabilities Request & Reply:
       //     The host should wait at least 50ms before sending the next message to the display
       // 4.8.1 Table Write
@@ -124,21 +130,7 @@ int get_sleep_time(
       //     The host should wait at least 50ms before sending the next message to the display
       spec_sleep_time_millis = DDC_TIMEOUT_MILLIS_BETWEEN_CAP_TABLE_FRAGMENTS;
       break;
-   case SE_POST_CAP_TABLE_COMMAND:
-      // unused, SE_AFTER_EACH_CAP_TABLE_SEGMENT called after each segment, not
-      // just between segments
-      deferrable_sleep = deferred_sleep_enabled;
-      spec_sleep_time_millis = DDC_TIMEOUT_MILLIS_POST_CAP_TABLE_COMMAND;
-      break;
-      // Not in DDC/CI spec
-   case SE_DDC_NULL:
-      spec_sleep_time_millis = DDC_TIMEOUT_MILLIS_NULL_RESPONSE_INCREMENT;
-      break;
-   case SE_PRE_MULTI_PART_READ:
-      // before reading capabilities - this is based on testing, not defined in spec
-      spec_sleep_time_millis = 200;
-      break;
-   case SE_SPECIAL:
+   case SE_SPECIAL:    // UNUSED
       // 4/2020: no current use
       spec_sleep_time_millis = special_sleep_time_millis;
       break;
@@ -163,7 +155,7 @@ int get_sleep_time(
  *  returned from dsa_update_adjustment_factor().
  *
  */
-int adjust_sleep_time(Display_Handle * dh, int spec_sleep_time_millis) {
+static int adjust_sleep_time(Display_Handle * dh, int spec_sleep_time_millis) {
    bool debug = false;
    DBGTRC_STARTING(debug, TRACE_GROUP,
                           "dh=%s, spec_sleep_time_millis=%d", dh_repr(dh), spec_sleep_time_millis);
@@ -268,6 +260,8 @@ void tuned_sleep_with_trace(
          g_snprintf(msg_buf, 100, "Event_type: %s", evname);
 
       sleep_millis_with_trace(adjusted_sleep_time_millis, func, lineno, filename, msg_buf);
+      Per_Thread_Data * ptd = ptd_get_per_thread_data();
+      ptd->total_sleep_time_millis += adjusted_sleep_time_millis;
    }
 
    DBGTRC_DONE(debug, TRACE_GROUP, "");
