@@ -3,7 +3,7 @@
  *  Parse the command line using the glib goption functions.
  */
 
-// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2023 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include <config.h>
@@ -143,10 +143,11 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    bool debug = false;
    char * s = getenv("DDCUTIL_DEBUG_PARSE");
    if (s && strlen(s) > 0)
-      debug = true;
-
+      debug = false;
    DBGMSF(debug, "Starting. parser_mode = %d", parser_mode );
+#ifndef NDEBUG
    init_cmd_parser_base();   // assertions
+#endif
 
    if (debug) {
       DBGMSG("argc=%d", argc);
@@ -174,7 +175,9 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    gboolean timestamp_trace_flag = false;
    gboolean wall_timestamp_trace_flag = false;
    gboolean thread_id_trace_flag = false;
+#ifdef ENABLE_SYSLOG
    gboolean syslog_flag    = false;
+#endif
    gboolean verify_flag    = false;
    gboolean noverify_flag  = false;
 #ifdef OLD
@@ -196,13 +199,12 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
 #endif
    gboolean timeout_i2c_io_flag = false;
    gboolean reduce_sleeps_specified = false;
-#ifdef OLD
-   gboolean reduce_sleeps_flag  = DEFAULT_SLEEP_LESS;
-#endif
    gboolean deferred_sleep_flag = false;
    gboolean per_thread_stats_flag = false;
    gboolean show_settings_flag = false;
    gboolean dsa_flag       = false;
+   gboolean i2c_io_fileio_flag = false;
+   gboolean i2c_io_ioctl_flag  = false;
    gboolean f1_flag        = false;
    gboolean f2_flag        = false;
    gboolean f3_flag        = false;
@@ -312,8 +314,12 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
 //    {"no-timeout-ddc-io",'\0',G_OPTION_FLAG_REVERSE,
 //                            G_OPTION_ARG_NONE,  &timeout_i2c_io_flag,   "Do not wrap DDC IO in timeout (default)",  NULL},
 
+#ifdef FUTURE
       {"force-slave-address",
                   '\0', 0, G_OPTION_ARG_NONE,     &force_slave_flag, "Deprecated",         NULL},
+#endif
+      {"force-slave-address",
+                  '\0', 0, G_OPTION_ARG_NONE,     &force_slave_flag, "Force I2C slave address",         NULL},
       {"force",   'f',  G_OPTION_FLAG_HIDDEN,
                            G_OPTION_ARG_NONE,     &force_flag,       "Ignore certain checks",           NULL},
       {"verify",  '\0', 0, G_OPTION_ARG_NONE,     &verify_flag,      "Read VCP value after setting it", NULL},
@@ -324,6 +330,11 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
                   '\0', 0, G_OPTION_ARG_NONE,     &enable_cc_flag,   enable_cc_expl,     NULL},
       {"disable-capabilities-cache", '\0', G_OPTION_FLAG_REVERSE,
                            G_OPTION_ARG_NONE,     &enable_cc_flag,   disable_cc_expl ,   NULL},
+      {"use-file-io",
+                  '\0', 0, G_OPTION_ARG_NONE,     &i2c_io_fileio_flag,"Use i2c-dev write()/read() calls by default",     NULL},
+      {"use-ioctl-io",
+                  '\0', 0, G_OPTION_ARG_NONE,     &i2c_io_ioctl_flag, "Use i2c-dev ioctl() calls by default",     NULL},
+
 
       {"udf",     '\0', 0, G_OPTION_ARG_NONE,     &enable_udf_flag,  enable_udf_expl,    NULL},
       {"enable-udf",'\0',0,G_OPTION_ARG_NONE,     &enable_udf_flag,  enable_udf_expl,    NULL},
@@ -377,7 +388,9 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
       {"wts",        '\0', 0, G_OPTION_ARG_NONE,         &wall_timestamp_trace_flag, "Prepend trace msgs with wall time",  NULL},
       {"thread-id",  '\0', 0, G_OPTION_ARG_NONE,         &thread_id_trace_flag, "Prepend trace msgs with thread id",  NULL},
       {"tid",        '\0', 0, G_OPTION_ARG_NONE,         &thread_id_trace_flag, "Prepend trace msgs with thread id",  NULL},
+#ifdef ENABLE_SYSLOG
       {"syslog",     '\0', 0, G_OPTION_ARG_NONE,         &syslog_flag,           "Write trace messages to system log",  NULL},
+#endif
       {"debug-parse",'\0', 0,  G_OPTION_ARG_NONE,        &debug_parse_flag,     "Report parsed command",    NULL},
       {"failsim",    '\0', 0,  G_OPTION_ARG_FILENAME,    &failsim_fn_work,      "Enable simulation", "control file name"},
 
@@ -513,8 +526,8 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
 
    if (reduce_sleeps_specified)
       fprintf(stderr, "Deprecated option ignored: --enable-sleep-less, --disable-sleep-less, etc.\n");
-   if (force_slave_flag)
-      fprintf(stderr, "Deprecated option ignored: --force_slave_address\n");
+   // if (force_slave_flag)
+   //    fprintf(stderr, "Deprecated option ignored: --force_slave_address\n");
    if (timeout_i2c_io_flag)
       fprintf(stderr, "Deprecated option ignored: --timeout-i2c-io\n");
 
@@ -536,13 +549,13 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    parsed_cmd->stats_types      = stats_work;
    parsed_cmd->i1               = i1_work;
    SET_CMDFLAG(CMD_FLAG_DDCDATA,           ddc_flag);
-#ifdef OLD
    SET_CMDFLAG(CMD_FLAG_FORCE_SLAVE_ADDR,  force_slave_flag);
-#endif
    SET_CMDFLAG(CMD_FLAG_TIMESTAMP_TRACE,   timestamp_trace_flag);
    SET_CMDFLAG(CMD_FLAG_WALLTIME_TRACE,    wall_timestamp_trace_flag);
    SET_CMDFLAG(CMD_FLAG_THREAD_ID_TRACE,   thread_id_trace_flag);
+#ifdef ENABLE_SYSLOG
    SET_CMDFLAG(CMD_FLAG_SYSLOG,            syslog_flag);
+#endif
    SET_CMDFLAG(CMD_FLAG_VERIFY,            verify_flag || !noverify_flag);
    // if (verify_flag || !noverify_flag)
    //    parsed_cmd->flags |= CMD_FLAG_VERIFY;
@@ -576,6 +589,8 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    SET_CMDFLAG(CMD_FLAG_X52_NO_FIFO,       x52_no_fifo_flag);
    SET_CMDFLAG(CMD_FLAG_PER_THREAD_STATS,  per_thread_stats_flag);
    SET_CMDFLAG(CMD_FLAG_SHOW_SETTINGS,     show_settings_flag);
+   SET_CMDFLAG(CMD_FLAG_I2C_IO_FILEIO,     i2c_io_fileio_flag);
+   SET_CMDFLAG(CMD_FLAG_I2C_IO_IOCTL,      i2c_io_ioctl_flag);
 
    SET_CLR_CMDFLAG(CMD_FLAG_ENABLE_CACHED_CAPABILITIES, enable_cc_flag);
 
@@ -760,7 +775,9 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
       float multiplier = 0.0f;
       bool arg_ok = str_to_float(sleep_multiplier_work, &multiplier);
       if (arg_ok) {
-         if (multiplier <= 0.0f || multiplier >= 100.0)
+         if (multiplier < 0.0f || multiplier >= 100.0)
+            arg_ok = false;
+         if (parser_mode == MODE_DDCUTIL && multiplier == 0.0f)
             arg_ok = false;
       }
 
@@ -892,7 +909,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
       puts("");
       // if no command specified, include license in version information and terminate
       if (rest_ct == 0) {
-         puts("Copyright (C) 2015-2022 Sanford Rockowitz");
+         puts("Copyright (C) 2015-2023 Sanford Rockowitz");
          puts("License GPLv2: GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>");
          puts("This is free software: you are free to change and redistribute it.");
          puts("There is NO WARRANTY, to the extent permitted by law.");
@@ -1021,6 +1038,13 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
             }
          }
 
+         if (parsing_ok && explicit_display_spec_ct == 1) {
+            if (!cmdInfo->supported_options & Option_Explicit_Display) {
+               fprintf(stderr, "%s does not support explicit display option\n", cmdInfo->cmd_name);
+               parsing_ok = false;
+            }
+         }
+
       }  // recognized command
    }
 
