@@ -14,6 +14,7 @@
 #include <string.h>
 #include <sys/stat.h>
 
+#include "util/data_structures.h"
 #include "util/report_util.h"
 #include "util/string_util.h"
 
@@ -269,11 +270,13 @@ ddc_report_display_by_dref(Display_Ref * dref, int depth) {
 // #endif
                 }
             }
+#ifdef TMI
             if (output_level >= DDCA_OL_VERBOSE) {
                if (!msg) {
                   msg = "Is DDC/CI enabled in the monitor's on-screen display?";
                }
             }
+#endif
          }
          if (msg) {
             rpt_vstring(d1, msg);
@@ -290,6 +293,7 @@ ddc_report_display_by_dref(Display_Ref * dref, int depth) {
          if (output_level >= DDCA_OL_VERBOSE) {
             // n. requires write access since may call get_vcp_value(), which does a write
             Display_Handle * dh = NULL;
+            DBGMSF(debug, "Calling ddc_open_display() ...");
             Public_Status_Code psc = ddc_open_display(dref, CALLOPT_ERR_MSG, &dh);
             if (psc != 0) {
                rpt_vstring(d1, "Error opening display %s, error = %s",
@@ -298,7 +302,8 @@ ddc_report_display_by_dref(Display_Ref * dref, int depth) {
             else {
                // display controller mfg, firmware version
                rpt_vstring(d1, "Controller mfg:      %s", get_controller_mfg_string_t(dh) );
-               rpt_vstring(d1, "Firmware version:    %s", get_firmware_version_string_t(dh));;
+               rpt_vstring(d1, "Firmware version:    %s", get_firmware_version_string_t(dh));
+               DBGMSF(debug, "Calling ddc_close_display()...");
                ddc_close_display(dh);
             }
 
@@ -336,6 +341,137 @@ ddc_report_display_by_dref(Display_Ref * dref, int depth) {
 }
 
 
+/** The following set of definitions and functions, called from ddc_report_displays(),
+ *  address a highly unlikely corner case, but one which has been reported.
+ *  (See https://github.com/rockowitz/ddcutil/issues/280)
+ *
+ *  Normally, the drm connector associated with an I2C bus, e.g. CARD0-DP-1,
+ *  is obtained by traversing /sys, starting with /sys/bus/i2c,
+ *  using function find_sys_drm_connector_by_busion().
+ *
+ *  However, it is possible that a driver does not put sufficient information
+ *  in /sys. This is the case with the proprietary nvidia driver. In this
+ *  situation function find_sys_drm_connector_by_edid() is used instead.
+ *  However, this method can give the wrong answer if two monitors have the same
+ *  EDID, i.e. the EDID inadequately distinguishes monitors.
+ *
+ *  In issue #280, the nvidia proprietary driver was in use, and there were two
+ *  identical Asus PG239Q monitors.  The EDID contained neither an ASCII nor a
+ *  binary serial number, and the monitors had the same manufacture year/week,
+ *  so the EDIDs were identical. In this case the wrong connector name was
+ *  reported for one monitor.
+ *
+ *  It is at least possible in this situation to warn the user that the
+ *  DRM connector name may be incorrect.
+ */
+typedef struct {
+   Byte * edid;                     ///< 128 byte EDID
+   Bit_Set_256 bus_numbers;         ///< numbers of the busses whose monitor has this EDID
+} EDID_Use_Record;
+
+
+/** Create array of #Edid_Use_Record
+ */
+static GPtrArray *
+create_edid_use_table() {
+   GPtrArray * result = g_ptr_array_new();
+   return result;
+}
+
+
+/** Frees an array of #Edid_Use_Record
+ */
+static void
+free_edid_use_table(GPtrArray* table) {
+      // free's each Edid_Use_Record, but not the edid the records point to
+      g_ptr_array_free(table, true);
+   }
+
+
+/** Returns the EDID_Use_Record for a particular EDID.
+ *  If one does not yet exist, it is created.
+ *
+ *  @param records #GPtrArray of #EDID_Use_Record
+ *  @param edid    edid to search for
+ *  @return #EDID_Use_Record
+ */
+static EDID_Use_Record *
+get_edid_use_record(GPtrArray * records, Byte * edid) {
+   assert(edid);
+   bool debug = false;
+   DBGTRC_STARTING(debug, DDCA_TRC_NONE, "records = %p, records->len = %d, edid -> ...%s",
+         records, records->len, hexstring_t(edid+122,6));
+
+   EDID_Use_Record * result = NULL;
+   for (int ndx = 0; ndx < records->len; ndx++) {
+      EDID_Use_Record * cur = g_ptr_array_index(records, ndx);
+      if (memcmp(cur->edid,edid,128) == 0) {
+         result = cur;
+         DBGTRC_DONE(debug, DDCA_TRC_NONE, "Returning existing EDID_Use_Record %p for edid %s",
+                       cur, hexstring_t(edid+122,6));
+         break;
+      }
+   }
+   if (!result) {
+      result = calloc(1, sizeof(EDID_Use_Record));
+      result->edid = edid;
+      DBGTRC_DONE(debug, DDCA_TRC_NONE, "Returning new EDID_Use_Record %p for edid %s",
+                    result, hexstring_t(edid+122,6) );
+      g_ptr_array_add(records, result);
+   }
+   return result;
+ }
+
+
+/** Record the #Display_Ref's I2C bus number in the #EDID_Use_Record
+ *  for the display.
+ *
+ *  @param records  #GPtrArray of #EDID_Use_Record
+ *  @param dref     display reference
+ *
+ *  @remark
+ *  Does nothing unless the display reference is for an I2C device and the
+ *  drm connector was found using the EDID.
+ */
+static void
+record_i2c_edid_use(GPtrArray * edid_use_records, Display_Ref * dref) {
+   bool debug = false;
+   DBGTRC_STARTING(debug, DDCA_TRC_NONE, "edid_use_records=%p, dref=%s", edid_use_records, dref_repr_t(dref));
+   if (dref->io_path.io_mode == DDCA_IO_I2C) {
+      I2C_Bus_Info * binfo = (I2C_Bus_Info *) dref->detail;
+      if (binfo -> drm_connector_found_by == DRM_CONNECTOR_FOUND_BY_EDID) {
+         EDID_Use_Record * cur = get_edid_use_record(edid_use_records, binfo->edid->bytes);
+         cur->bus_numbers = bs256_insert(cur->bus_numbers, binfo->busno);
+         DBGTRC_DONE(debug, DDCA_TRC_NONE, "Updated bus list %s for edid %s",
+                         bs256_to_string_decimal(cur->bus_numbers, NULL, ", "),
+                         hexstring_t(binfo->edid->bytes+122,6));
+      }
+   }
+}
+
+
+/** Report i2c buses having identical EDID, for which the DRM
+ *  connector name was found using the EDID
+ *
+ *  @param  edid_use_records  GPtrArray of #EDID_Use_Record
+ *  @param  depth             logical indentation depth
+ */
+static void
+report_ambiguous_connector_for_edid(GPtrArray * edid_use_records, int depth) {
+   bool debug = false;
+   DBGTRC_STARTING(debug, DDCA_TRC_NONE, "edid_use_records->len = %d", edid_use_records->len);
+   for (int ndx = 0; ndx < edid_use_records->len; ndx++) {
+      EDID_Use_Record * cur_use_record = g_ptr_array_index(edid_use_records, ndx);
+      if (bs256_count(cur_use_record->bus_numbers) > 1) {
+         rpt_vstring(depth,"Displays with I2C bus numbers %s have identical EDIDs.",
+                             bs256_to_string_decimal(cur_use_record->bus_numbers, NULL, ", "));
+         rpt_label(depth, "DRM connector names may not be accurate.");
+      }
+   }
+   DBGTRC_DONE(debug, DDCA_TRC_NONE, "");
+}
+
+
 /** Reports all displays found.
  *
  * Output is written to the current report destination using report functions.
@@ -349,12 +485,14 @@ ddc_report_display_by_dref(Display_Ref * dref, int depth) {
 int
 ddc_report_displays(bool include_invalid_displays, int depth) {
    bool debug = false;
-   DBGMSF(debug, "Starting");
+   DBGTRC_STARTING(debug, TRACE_GROUP, "");
 
    ddc_ensure_displays_detected();
 
    int display_ct = 0;
    GPtrArray * all_displays = ddc_get_all_displays();
+   GPtrArray * edid_use_records = create_edid_use_table();
+   // DBGTRC_NOPREFIX(debug, DDCA_TRC_NONE, "Created edid_use_records = %p", edid_use_records);
    for (int ndx=0; ndx<all_displays->len; ndx++) {
       Display_Ref * dref = g_ptr_array_index(all_displays, ndx);
       TRACED_ASSERT(memcmp(dref->marker, DISPLAY_REF_MARKER, 4) == 0);
@@ -362,17 +500,24 @@ ddc_report_displays(bool include_invalid_displays, int depth) {
          display_ct++;
          ddc_report_display_by_dref(dref, depth);
          rpt_title("",0);
+
+         // Note the EDID for each bus
+         record_i2c_edid_use(edid_use_records, dref);
       }
    }
    if (display_ct == 0) {
       rpt_vstring(depth, "No %sdisplays found.", (!include_invalid_displays) ? "active " : "");
       if ( get_output_level() >= DDCA_OL_NORMAL ) {
-         rpt_label(depth, "Is DDC/CI enabled in the monitor's on screen display?");
+         // rpt_label(depth, "Is DDC/CI enabled in the monitor's on screen display?");
          rpt_label(depth, "Run \"ddcutil environment\" to check for system configuration problems.");
       }
    }
+   else if (get_output_level() >= DDCA_OL_VERBOSE && display_ct > 1) {
+      report_ambiguous_connector_for_edid(edid_use_records, depth);
+   }
+   free_edid_use_table(edid_use_records);
 
-   DBGMSF(debug, "Done.     Returning: %d", display_ct);
+   DBGTRC_DONE(debug, TRACE_GROUP, "Returning: %d", display_ct);
    return display_ct;
 }
 
@@ -384,22 +529,18 @@ ddc_report_displays(bool include_invalid_displays, int depth) {
  */
 void
 ddc_dbgrpt_display_ref(Display_Ref * dref, int depth) {
+   assert(dref);
+   bool debug = false;
+   DBGMSF(debug, "Starting. dref=%s", dref_repr_t(dref));
    int d1 = depth+1;
    int d2 = depth+2;
-   // no longer needed for i2c_dbgreport_bus_info()
-   // DDCA_Output_Level saved_output_level = get_output_level();
-   // set_output_level(DDCA_OL_VERBOSE);
+
    rpt_structure_loc("Display_Ref", dref, depth);
    rpt_int("dispno", NULL, dref->dispno, d1);
 
-   // rpt_vstring(d1, "dref: %p:", dref->dref);
    dbgrpt_display_ref(dref, d1);
 
-   rpt_vstring(d1, "edid: %p (Skipping report)", dref->pedid);
-   // report_parsed_edid(drec->edid, false, d1);
-
    rpt_vstring(d1, "io_mode: %s", io_mode_name(dref->io_path.io_mode));
-   // rpt_vstring(d1, "flags:   0x%02x", drec->flags);
    switch(dref->io_path.io_mode) {
    case(DDCA_IO_I2C):
          rpt_vstring(d1, "I2C bus information: ");
@@ -423,6 +564,7 @@ ddc_dbgrpt_display_ref(Display_Ref * dref, int depth) {
    }
 
    // set_output_level(saved_output_level);
+   DBGMSF(debug, "Done");
 }
 
 
@@ -468,9 +610,14 @@ void dbgrpt_valid_display_refs(int depth) {
 
 
 void init_ddc_display_ref_reports() {
-   RTTI_ADD_FUNC(get_controller_mfg_string_t);
-   RTTI_ADD_FUNC(get_firmware_version_string_t);
+
    RTTI_ADD_FUNC(ddc_report_display_by_dref);
+   RTTI_ADD_FUNC(ddc_report_displays);
+   RTTI_ADD_FUNC(get_controller_mfg_string_t);
+   RTTI_ADD_FUNC(get_edid_use_record);
+   RTTI_ADD_FUNC(get_firmware_version_string_t);
+   RTTI_ADD_FUNC(record_i2c_edid_use);
+   RTTI_ADD_FUNC(report_ambiguous_connector_for_edid);
 }
 
 
