@@ -4,7 +4,7 @@
  *  This file and ddc_display_ref_reports.c cross-reference each other.
  */
 
-// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2023 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "config.h"
@@ -122,7 +122,7 @@ value_bytes_zero_for_any_value(DDCA_Any_Vcp_Value * pvalrec) {
  *  ADL does not notice that a reported display, e.g. Dell 1905FP, does not support
  *  DDC.
  *  @remark
- *  Monitors are supposed to set the unsupported feFFature bit in a valid DDC
+ *  Monitors are supposed to set the unsupported feature bit in a valid DDC
  *  response, but a few monitors (mis)use the Null Response instead to indicate
  *  an unsupported feature. Others return with the unsupported feature bit not
  *  set, but all bytes (mh, ml, sh, sl) zero.
@@ -144,9 +144,8 @@ ddc_initial_checks_by_dh(Display_Handle * dh) {
    DDCA_Any_Vcp_Value * pvalrec;
 
    if (!(dh->dref->flags & DREF_DDC_COMMUNICATION_CHECKED)) {
-      Public_Status_Code psc = 0;
       Error_Info * ddc_excp = ddc_get_vcp_value(dh, 0x00, DDCA_NON_TABLE_VCP_VALUE, &pvalrec);
-      psc = (ddc_excp) ? ddc_excp->status_code : 0;
+      Public_Status_Code psc = (ddc_excp) ? ddc_excp->status_code : 0;
       DBGTRC_NOPREFIX(debug, TRACE_GROUP, "ddc_get_vcp_value() for feature 0x00 returned: %s, pvalrec=%p",
                              errinfo_summary(ddc_excp), pvalrec);
       TRACED_ASSERT( (psc == 0 && pvalrec) || (psc != 0 && !pvalrec) );
@@ -201,10 +200,12 @@ ddc_initial_checks_by_dh(Display_Handle * dh) {
          }  // end, communication working
 
          else {   // communication failed
-            if ( i2c_force_bus /* && psc == DDCRC_RETRIES */) {
+            if (psc == -EBUSY) {
+               dh->dref->flags |= DREF_DDC_BUSY;
+            }
+            else if ( i2c_force_bus /* && psc == DDCRC_RETRIES */) {
                DBGTRC_NOPREFIX(debug || true , TRACE_GROUP, "dh=%s, Forcing DDC communication success.",
                      dh_repr(dh) );
-               psc = 0;
                dh->dref->flags |= DREF_DDC_COMMUNICATION_WORKING;
             // dh->dref->flags |= DREF_DDC_DOES_NOT_INDICATE_UNSUPPORTED;
                dh->dref->flags |= DREF_DDC_USES_DDC_FLAG_FOR_UNSUPPORTED;   // good_enuf_for_test
@@ -316,7 +317,7 @@ void ddc_async_scan(GPtrArray * all_displays) {
 }
 
 
-/** Loops through a list of display refs, performing  initial checks on each.
+/** Loops through a list of display refs, performing initial checks on each.
  *
  *  @param all_displays #GPtrArray of pointers to #Display_Ref
  */
@@ -603,6 +604,7 @@ ddc_detect_all_displays(GPtrArray ** i2c_open_errors_loc) {
          dref->flags |= DREF_DDC_IS_MONITOR_CHECKED;
          dref->flags |= DREF_DDC_IS_MONITOR;
          g_ptr_array_add(display_list, dref);
+         // dbgrpt_display_ref(dref,5);
       }
       else if ( !(businfo->flags & I2C_BUS_ACCESSIBLE) ) {
          Bus_Open_Error * boe = calloc(1, sizeof(Bus_Open_Error));
@@ -863,6 +865,7 @@ void
 init_ddc_displays() {
    RTTI_ADD_FUNC(ddc_async_scan);
    RTTI_ADD_FUNC(ddc_detect_all_displays);
+   RTTI_ADD_FUNC(ddc_get_all_displays);
    RTTI_ADD_FUNC(ddc_initial_checks_by_dh);
    RTTI_ADD_FUNC(ddc_initial_checks_by_dref);
    RTTI_ADD_FUNC(ddc_is_valid_display_ref);
