@@ -132,7 +132,6 @@ void ddc_dbgrpt_valid_display_handles(int depth) {
  *
  *  **Call_Option** flags recognized:
  *  - CALLOPT_WAIT
- *  - CALLOPT_ERR_MSG
  */
 DDCA_Status
 ddc_open_display(
@@ -182,6 +181,7 @@ ddc_open_display(
          TRACED_ASSERT(bus_info);   // need to convert to a test?
          TRACED_ASSERT( bus_info && memcmp(bus_info, I2C_BUS_INFO_MARKER, 4) == 0);
 
+         DBGMSF(debug, "Calling i2c_open_bus() ...");
          int fd = i2c_open_bus(dref->io_path.path.i2c_busno, callopts);
          if (fd < 0) {
             ddcrc = fd;
@@ -286,6 +286,7 @@ ddc_close_display(Display_Handle * dh) {
       switch(dh->dref->io_path.io_mode) {
       case DDCA_IO_I2C:
          {
+            DBGMSF(debug, "Calling is2_close_bus() ...");
             rc = i2c_close_bus(dh->fd, CALLOPT_NONE);
             if (rc != 0) {
                TRACED_ASSERT(rc < 0);
@@ -532,7 +533,7 @@ ddc_write_read(
                                        " expected_response_type=0x%02x, expected_subtype=0x%02x",
           dh_repr(dh), SBOOL(read_bytewise), max_read_bytes, expected_response_type, expected_subtype  );
 
-   DBGTRC_NOPREFIX(debug, DDCA_TRC_NONE, "Adding 1 to max_read_bytes to allow for initail double 0x63 quirk");
+   DBGTRC_NOPREFIX(debug, DDCA_TRC_NONE, "Adding 1 to max_read_bytes to allow for initial double 0x63 quirk");
    max_read_bytes++;   //allow for quirk of double 0x6e at start
    Byte * readbuf = calloc(1, max_read_bytes);
    int    bytes_received = max_read_bytes;
@@ -578,7 +579,7 @@ ddc_write_read(
    // Convert status code to Error_Info *
    Error_Info * excp = NULL;
    if (psc < 0)
-      excp = errinfo_new(psc, __func__);
+      excp = errinfo_new(psc, __func__, NULL);
 
    DBGTRC_RET_ERRINFO_STRUCT(debug, TRACE_GROUP, excp, response_packet_ptr_loc, dbgrpt_packet);
 #ifdef OLD
@@ -725,6 +726,10 @@ ddc_write_read_with_retry(
               retryable = false;  // have seen success after 7 retries of errors including ENXIO, DDCRC_DATA, make retryable?
               break;
 
+         case (-EBUSY):
+               retryable = false;
+               break;
+
          default:
               retryable = true;     // for now
          }
@@ -779,7 +784,7 @@ ddc_write_read_with_retry(
       else if (ddcrc_null_response_ct > ddcrc_null_response_max)
          psc = DDCRC_ALL_RESPONSES_NULL;
 
-      ddc_excp = errinfo_new_with_causes(psc, try_errors, tryctr, __func__);
+      ddc_excp = errinfo_new_with_causes(psc, try_errors, tryctr, __func__, NULL);
 
       if (psc != try_errors[tryctr-1]->status_code)
          COUNT_STATUS_CODE(psc);     // new status code, count it
@@ -824,9 +829,6 @@ ddc_i2c_write_only(
                               hexstring3_t(request_packet_ptr->raw_bytes->bytes,
                                            request_packet_ptr->raw_bytes->len,
                                            " ", 1, false) );
-
-   // Byte slave_address = request_packet_ptr[0];
-   // assert(slave_address == 0x37);
    Byte slave_address = 0x37;
 
    CHECK_DEFERRED_SLEEP(dh);
@@ -841,7 +843,6 @@ ddc_i2c_write_only(
          (request_packet_ptr->type == DDC_PACKET_TYPE_SAVE_CURRENT_SETTINGS )
             ? SE_POST_SAVE_SETTINGS
             : SE_POST_WRITE;
-   // tuned_sleep_i2c_with_trace(sleep_type, __func__, NULL);
    TUNED_SLEEP_WITH_TRACE(dh, sleep_type, NULL);
    DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "");
    return rc;
@@ -871,7 +872,7 @@ ddc_write_only(
    DDCA_Status psc = ddc_i2c_write_only(dh, request_packet_ptr);
    Error_Info *  ddc_excp = NULL;
    if (psc)
-      ddc_excp = errinfo_new(psc, __func__);
+      ddc_excp = errinfo_new(psc, __func__, NULL);
 
    DBGTRC_DONE(debug, TRACE_GROUP, "Returning: %s", errinfo_summary(ddc_excp));
    return ddc_excp;
@@ -915,6 +916,8 @@ ddc_write_only_with_retry(
       Error_Info * cur_excp = ddc_write_only(dh, request_packet_ptr);
       psc = (cur_excp) ? cur_excp->status_code : 0;
       try_errors[tryctr] = cur_excp;
+      if (psc == -EBUSY)
+         retryable = false;
 
       // try_status_codes[tryctr] = psc;   // for future Ddc_Error mechanism
    }
@@ -933,13 +936,18 @@ ddc_write_only_with_retry(
       DBGTRC_NOPREFIX(debug, TRACE_GROUP, "After try loop. tryctr=%d, retryable=%s",
                                            tryctr, sbool(retryable));
 
-      if (retryable)
+      if (retryable) {
          psc = DDCRC_RETRIES;
 
-      ddc_excp = errinfo_new_with_causes(psc, try_errors, tryctr, __func__);
+         ddc_excp = errinfo_new_with_causes(psc, try_errors, tryctr, __func__, NULL);
 
-      if (psc != try_errors[tryctr-1]->status_code)
-         COUNT_STATUS_CODE(psc);     // new status code, count it
+         if (psc != try_errors[tryctr-1]->status_code)
+            COUNT_STATUS_CODE(psc);     // new status code, count it
+      }
+      else {
+         assert (tryctr == 1);
+         ddc_excp = try_errors[0];
+      }
    }
    else {
       // 2 possibilities:
