@@ -1,4 +1,5 @@
 /** @file ddc_services.c
+#include <base/base_services.h>
  *
  * ddc layer initialization and configuration, statistics management
  */
@@ -14,7 +15,6 @@
 #include "util/report_util.h"
 /** \endcond */
 
-#include "base/base_init.h"
 #include "base/feature_metadata.h"
 #include "base/parms.h"
 #include "base/rtti.h"
@@ -30,12 +30,9 @@
 #include "dynvcp/dyn_feature_codes.h"
 #include "dynvcp/dyn_feature_files.h"
 
-#include "i2c/i2c_bus_core.h"
-#include "i2c/i2c_strategy_dispatcher.h"
-#include "i2c/i2c_sysfs.h"
-#ifdef USE_USB
+#include "i2c/i2c_services.h"
+
 #include "usb/usb_displays.h"
-#endif
 
 #include "ddc/ddc_display_lock.h"
 #include "ddc/ddc_displays.h"
@@ -158,8 +155,7 @@ void init_ddc_services() {
    DBGMSF(debug, "Starting");
 
    // i2c:
-   init_i2c_bus_core();
-   init_i2c_sysfs();
+   init_i2c_services();
 
    // usb
 #ifdef USE_USB
