@@ -94,7 +94,8 @@ ddc_save_current_settings(
    if (dh->dref->io_path.io_mode == DDCA_IO_USB) {
       // command line parser should block this case
       PROGRAM_LOGIC_ERROR("MCCS over USB does not have Save Current Settings command");
-      ddc_excp = errinfo_new(DDCRC_UNIMPLEMENTED, __func__);
+      ddc_excp = errinfo_new(DDCRC_UNIMPLEMENTED, __func__,
+                              "MCCS over USB does not have Save Current Settings command" );
    }
    else {
       DDC_Packet * request_packet_ptr =
@@ -195,7 +196,7 @@ set_table_vcp_value(
       PROGRAM_LOGIC_ERROR("ddcutil not built with USB support");
       psc = DDCRC_INTERNAL_ERROR;
 #endif
-      ddc_excp = ERRINFO_NEW(psc);
+      ddc_excp = errinfo_new(psc, __func__, "Error setting feature value");
    }
    else {
       // TODO: clean up function signatures
@@ -409,7 +410,7 @@ ddc_set_vcp_value(
             // dbgrpt_ddca_single_vcp_value(newval, 3);
 
             if (! single_vcp_value_equal(vrec,newval)) {
-               ddc_excp = errinfo_new(DDCRC_VERIFY, __func__);
+               ddc_excp = errinfo_new(DDCRC_VERIFY, __func__, "Current value does not match value set");
                f0printf(verbose_msg_dest, "Current value does not match value set.\n");
             }
             else {
@@ -476,7 +477,7 @@ mock_get_nontable_vcp_value(
 
 #ifdef TEST_EIO
    if (feature_code == 0x45) {
-      pseudo_errinfo = errinfo_new2(-EIO, __func__, "Pseudo EIO error");
+      pseudo_errinfo = errinfo_new(-EIO, __func__, "Pseudo EIO error");
    }
 #endif
 
@@ -575,10 +576,10 @@ ddc_get_nontable_vcp_value(
 #endif
 
          if (!parsed_response->valid_response)  {
-            excp = errinfo_new(DDCRC_DDC_DATA, __func__);  // was DDCRC_INVALID_DATA
+            excp = errinfo_new(DDCRC_DDC_DATA, __func__, "Invalid getvcp response");  // was DDCRC_INVALID_DATA
          }
          else if (!parsed_response->supported_opcode) {
-            excp = errinfo_new(DDCRC_REPORTED_UNSUPPORTED, __func__);
+            excp = errinfo_new(DDCRC_REPORTED_UNSUPPORTED, __func__, "Unsupported feature");
             if (!value_bytes_zero(parsed_response)) {
                // for exploring
                DBGMSG("supported_opcode == false, but not all value bytes 0");
@@ -590,7 +591,7 @@ ddc_get_nontable_vcp_value(
             // just a messages for now
             DBGMSG("all value bytes 0, supported_opcode == true,"
                    " setting DDCRC_DETERMINED_UNSUPPORTED)");
-            excp = errinfo_new2(DDCRC_DETERMINED_UNSUPPORTED, __func__, "MH=ML=SH=SL=0");
+            excp = errinfo_new(DDCRC_DETERMINED_UNSUPPORTED, __func__, "MH=ML=SH=SL=0");
          }
 
          if (excp) {
@@ -599,7 +600,7 @@ ddc_get_nontable_vcp_value(
          }
       }
       else {
-         excp = errinfo_new(psc, __func__);
+         excp = errinfo_new(psc, __func__, NULL);
       }
    }
 
@@ -671,7 +672,7 @@ ddc_get_table_vcp_value(
             ddc_excp->status_code == DDCRC_ALL_RESPONSES_NULL)
    {
       Error_Info * wrapped_exception = ddc_excp;
-      ddc_excp = errinfo_new_with_cause2(
+      ddc_excp = errinfo_new_with_cause(
             DDCRC_DETERMINED_UNSUPPORTED, wrapped_exception, __func__, "DDC NULL Message");
    }
 
@@ -731,11 +732,12 @@ ddc_get_vcp_value(
                    free(parsed_nontable_response);
                 }
                 else
-                   ddc_excp = errinfo_new(psc, __func__);
+                   ddc_excp = errinfo_new(psc, __func__, NULL);
                 break;
 
           case (DDCA_TABLE_VCP_VALUE):
-                ddc_excp = errinfo_new(DDCRC_UNIMPLEMENTED, __func__);
+                ddc_excp = errinfo_new(DDCRC_UNIMPLEMENTED, __func__,
+                                        "Table features not supported for USB connection");
                 break;
           }
 #else
