@@ -1,10 +1,11 @@
-/** \file ddc_watch_displays.c - Watch for monitor addition and removal
- */
+/** @file ddc_watch_displays.c  Watch for monitor addition and removal */
 
 // Copyright (C) 2021-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "config.h"
+#include "public/ddcutil_types.h"
+#include "ddc/ddc_watch_displays.h"
 
 /** \cond */
 #include <assert.h>
@@ -18,11 +19,13 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/stat.h>
+#include <unistd.h>
 
 #include "util/data_structures.h"
 #include "util/file_util.h"
 #include "util/glib_string_util.h"
 #include "util/glib_util.h"
+#include "util/linux_util.h"
 #include "util/report_util.h"
 #include "util/string_util.h"
 #include "util/sysfs_filter_functions.h"
@@ -35,7 +38,6 @@
 #include "base/rtti.h"
 /** \endcond */
 
-#include "ddc/ddc_watch_displays.h"
 
 // Experimental code
 static bool watch_displays_enabled = true;
@@ -53,7 +55,7 @@ typedef struct {
    Display_Change_Handler display_change_handler;
    pid_t                  main_process_id;
    pid_t                  main_thread_id;
-   Byte_Bit_Flags         drm_card_numbers;
+   Bit_Set_256            drm_card_numbers;
 } Watch_Displays_Data;
 
 
@@ -209,6 +211,8 @@ void get_sysfs_drm_examine_one_connector(
 }
 
 
+
+
 static
 GPtrArray * get_sysfs_drm_displays() {
    bool debug = false;
@@ -245,22 +249,22 @@ static GPtrArray * check_displays(GPtrArray * prev_displays, gpointer data) {
    // typedef enum _change_type {Changed_None = 0, Changed_Added = 1, Changed_Removed = 2, Changed_Both = 3 } Change_Type;
    Displays_Change_Type change_type = Changed_None;
 
-   GPtrArray * cur_displays = get_sysfs_drm_displays(wdd->drm_card_numbers, false);
-   if ( !gaux_string_ptr_arrays_equal(prev_displays, cur_displays) ) {
+   GPtrArray * cur_displays = get_sysfs_drm_displays();
+   if ( !gaux_unique_string_ptr_arrays_equal(prev_displays, cur_displays) ) {
       if ( debug || IS_TRACING() ) {
          DBGMSG("Displays changed!");
          DBGMSG("Previous connected displays: %s", join_string_g_ptr_array_t(prev_displays, ", "));
          DBGMSG("Current  connected displays: %s", join_string_g_ptr_array_t(cur_displays,  ", "));
       }
 
-      GPtrArray * removed = gaux_string_ptr_arrays_minus(prev_displays, cur_displays);
+      GPtrArray * removed = gaux_unique_string_ptr_arrays_minus(prev_displays, cur_displays);
       if (removed->len > 0) {
          DBGTRC_NOPREFIX(debug, TRACE_GROUP,
                 "Removed displays: %s", join_string_g_ptr_array_t(removed, ", ") );
          change_type = Changed_Removed;
       }
 
-      GPtrArray * added = gaux_string_ptr_arrays_minus(cur_displays, prev_displays);
+      GPtrArray * added = gaux_unique_string_ptr_arrays_minus(cur_displays, prev_displays);
       if (added->len > 0) {
          DBGTRC_NOPREFIX(debug, TRACE_GROUP,
                 "Added displays: %s", join_string_g_ptr_array_t(added, ", ") );
@@ -296,7 +300,7 @@ gpointer watch_displays_using_poll(gpointer data) {
    Watch_Displays_Data * wdd = data;
    assert(wdd && memcmp(wdd->marker, WATCH_DISPLAYS_DATA_MARKER, 4) == 0);
 
-   GPtrArray * prev_displays = get_sysfs_drm_displays(wdd->drm_card_numbers, false);
+   GPtrArray * prev_displays = get_sysfs_drm_displays();
    DBGTRC_NOPREFIX(debug, TRACE_GROUP,
           "Initial connected displays: %s", join_string_g_ptr_array_t(prev_displays, ", ") );
 
@@ -539,8 +543,8 @@ ddc_start_watch_displays()
    #else
             "/sys/class/drm";
    #endif
-      Byte_Bit_Flags drm_card_numbers = get_sysfs_drm_card_numbers();
-      if (bbf_count_set(drm_card_numbers) == 0) {
+      Bit_Set_256 drm_card_numbers = get_sysfs_drm_card_numbers();
+      if (bs256_count(drm_card_numbers) == 0) {
          rpt_vstring(0, "No video cards found in %s. Disabling experimental detection of display hotplug events.", class_drm_dir);
          ddcrc = DDCRC_INVALID_OPERATION;
       }
@@ -570,8 +574,8 @@ ddc_start_watch_displays()
          g_mutex_unlock(&watch_thread_mutex);
       }
    }
-   DBGTRC_RETURNING(debug, TRACE_GROUP, ddcrc, "watch_displays_enabled=%s. watch_thread=%p",
-                                        watch_displays_enabled, watch_thread);
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, ddcrc, "watch_displays_enabled=%s. watch_thread=%p",
+                                        SBOOL(watch_displays_enabled), watch_thread);
    return ddcrc;
 }
 
@@ -615,7 +619,7 @@ ddc_stop_watch_displays()
       g_mutex_unlock(&watch_thread_mutex);
 
    }
-   DBGTRC_RETURNING(debug, TRACE_GROUP, ddcrc, "watch_thread=%p", watch_thread);
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, ddcrc, "watch_thread=%p", watch_thread);
    return ddcrc;
 }
 
