@@ -1,21 +1,15 @@
-/** \file ddc_watch_displays.h - Watch for monitor addition and removal
- */
+/** @file ddc_watch_displays.h  Watch for monitor addition and removal  */
 
-// Copyright (C) 2019-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2019-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef DDC_WATCH_DISPLAYS_H_
 #define DDC_WATCH_DISPLAYS_H_
 
 /** \cond */
-// for syscall
-#define _GNU_SOURCE
-#include <unistd.h>
-
 #include <glib-2.0/glib.h>
 
-#include "ddcutil_status_codes.h"
-
+#include "public/ddcutil_types.h"
 /** \endcond */
 
 typedef enum {Changed_None    = 0,
@@ -40,6 +34,4 @@ DDCA_Status ddc_start_watch_displays();
 DDCA_Status ddc_stop_watch_displays();
 void init_ddc_watch_displays();
 
-// GPtrArray *  get_sysfs_drm_displays();
-
 #endif /* DDC_WATCH_DISPLAYS_H_ */
