@@ -21,6 +21,7 @@
 #include <unistd.h>
 /** \endcond */
 
+#include "util/coredefs_base.h"
 #include "util/debug_util.h"
 #include "util/failsim.h"
 #include "util/file_util.h"
@@ -57,6 +58,7 @@
 #include "i2c/i2c_strategy_dispatcher.h"
 #include "i2c/i2c_sysfs.h"
 #include "i2c/i2c_execute.h"
+#include "i2c/i2c_edid.h"
 
 #include "i2c/i2c_bus_core.h"
 
@@ -64,13 +66,10 @@
 // Trace class for this file
 static DDCA_Trace_Group TRACE_GROUP = DDCA_TRC_I2C;
 
-bool EDID_Read_Bytewise              = DEFAULT_EDID_READ_BYTEWISE;
-int  EDID_Read_Size                  = DEFAULT_EDID_READ_SIZE;
-bool EDID_Write_Before_Read          = DEFAULT_EDID_WRITE_BEFORE_READ;
-
 /** All I2C buses.  GPtrArray of pointers to #I2C_Bus_Info - shared with i2c_bus_selector.c */
 /* static */ GPtrArray * i2c_buses = NULL;
 
+// Another ugly global variable for testing purposes
 bool i2c_force_bus = false;
 
 static GMutex  open_failures_mutex;
@@ -106,6 +105,7 @@ static char * interpret_i2c_bus_flags(uint16_t flags) {
    ADD_NAME(I2C_BUS_HAS_VALID_NAME     );
    ADD_NAME(I2C_BUS_BUSY               );
    ADD_NAME(I2C_BUS_SYSFS_EDID         );
+   ADD_NAME(I2C_BUS_DRM_CONNECTOR_CHECKED);
 
 #undef ADD_NAME
 
@@ -282,172 +282,6 @@ static bool is_laptop_drm_connector(int busno, char * drm_name_fragment) {
 }
 
 
-//
-// I2C Bus Inspection - EDID Retrieval
-//
-
-static Status_Errno_DDC
-i2c_get_edid_bytes_using_i2c_layer(
-      int     fd,
-      Buffer* rawedid,
-      int     edid_read_size,
-      bool    read_bytewise)
-{
-   bool debug = false;
-   DBGTRC_STARTING(debug, TRACE_GROUP, "fd=%d, filename=%s, rawedid=%p, edid_read_size=%d, read_bytewise=%s",
-                 fd, filename_for_fd_t(fd), (void*)rawedid, edid_read_size, sbool(read_bytewise));
-   assert(rawedid && rawedid->buffer_size >= EDID_BUFFER_SIZE);
-
-   bool write_before_read = EDID_Write_Before_Read;
-   int rc = 0;
-   if (write_before_read) {
-      Byte byte_to_write = 0x00;
-      rc = invoke_i2c_writer(fd, 0x50, 1, &byte_to_write);
-      DBGMSF(debug, "invoke_i2c_writer returned %s", psc_desc(rc));
-   }
-   if (rc == 0) {   // write succeeded or no write
-      if (read_bytewise) {
-         int ndx = 0;
-         for (; ndx < edid_read_size && rc == 0; ndx++) {
-            // DBGMSG("Before invoke_i2c_reader() call");
-            rc = invoke_i2c_reader(fd, 0x50, false, 1, &rawedid->bytes[ndx] );
-         }
-         DBGMSF(debug, "Final single byte read returned %d, ndx=%d", rc, ndx);
-      } // read_bytewise == true
-      else {
-         rc = invoke_i2c_reader(fd, 0x50, read_bytewise, edid_read_size, rawedid->bytes);
-         DBGMSF(debug, "invoke_i2c_reader returned %s", psc_desc(rc));
-
-      }
-      if (rc == 0) {
-         rawedid->len = edid_read_size;
-      }
-   }  // write succeeded
-   if ( (debug || IS_TRACING()) && rc == 0) {
-      DBGMSG("Returning buffer:");
-      rpt_hex_dump(rawedid->bytes, rawedid->len, 2);
-   }
-   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "");
-   return rc;
-}
-
-
-/** Gets EDID bytes of a monitor on an open I2C device.
- *
- * @param  fd        file descriptor for open /dev/i2c-n
- * @param  rawedid   buffer in which to return bytes of the EDID
- *
- * @retval  0        success
- * @retval  <0       error
- */
-Status_Errno_DDC
-i2c_get_raw_edid_by_fd(int fd, Buffer * rawedid)
-{
-   bool debug  = false;
-   DBGTRC_STARTING(debug, TRACE_GROUP, "Getting EDID. File descriptor = %d, filename=%s",
-                              fd, filename_for_fd_t(fd));
-   assert(rawedid && rawedid->buffer_size >= EDID_BUFFER_SIZE);
-   Status_Errno_DDC rc;
-   int tryctr = 0;
-   int max_tries = (EDID_Read_Size == 0) ?  4 : 2;
-   DBGTRC_NOPREFIX(debug, TRACE_GROUP, "EDID_Read_Size=%d, max_tries=%d", EDID_Read_Size);
-   rc = -1;
-
-   bool read_bytewise = EDID_Read_Bytewise;
-   for (tryctr = 0; tryctr < max_tries && rc != 0; tryctr++) {
-      int edid_read_size = EDID_Read_Size;
-      if (EDID_Read_Size == 0)
-         edid_read_size = (tryctr < 2) ? 128 : 256;
-      DBGTRC_NOPREFIX(debug, TRACE_GROUP,
-                    "Trying EDID read. tryctr=%d, max_tries=%d,"
-                    " edid_read_size=%d, read_bytewise=%s",
-                    tryctr, max_tries, edid_read_size, sbool(read_bytewise) );
-      rc = i2c_get_edid_bytes_using_i2c_layer(fd, rawedid, edid_read_size, read_bytewise);
-      if (rc == -ENXIO || rc == -EOPNOTSUPP || rc == -ETIMEDOUT) {    // removed -EIO 3/4/2021
-         // DBGMSG("breaking");
-         break;
-      }
-      assert(rc <= 0);
-      if (rc == 0) {
-         // rawedid->len = 128;
-         if (IS_DBGTRC(debug, DDCA_TRC_NONE) ) {  // only show if explicitly tracing this function
-            DBGMSG("get bytes returned:");
-            dbgrpt_buffer(rawedid, 1);
-            DBGMSG("edid checksum = %d", edid_checksum(rawedid->bytes) );
-         }
-         if (!is_valid_raw_edid(rawedid->bytes, rawedid->len)) {
-            DBGTRC_NOPREFIX(debug, TRACE_GROUP, "Invalid EDID");
-            rc = DDCRC_INVALID_EDID;
-            if (is_valid_raw_cea861_extension_block(rawedid->bytes, rawedid->len)) {
-               DBGTRC_NOPREFIX(debug, TRACE_GROUP,
-                               "EDID appears to start with a CEA 861 extension block");
-            }
-         }
-         if (rawedid->len == 256) {
-            if (is_valid_raw_cea861_extension_block(rawedid->bytes+128, rawedid->len-128)) {
-               DBGTRC_NOPREFIX(debug, TRACE_GROUP,
-                               "Second physical EDID block appears to be a CEA 861 extension block");
-            }
-            else if (is_valid_raw_edid(rawedid->bytes+128, rawedid->len-128)) {
-               DBGTRC_NOPREFIX(debug, TRACE_GROUP,
-                               "Second physical EDID block read is actually the initial EDID block");
-               memcpy(rawedid->bytes, rawedid->bytes+128, 128);
-               buffer_set_length(rawedid, 128);
-               rc = 0;
-            }
-         }
-      }  // get bytes succeeded
-   }
-
-   if (rc < 0)
-      rawedid->len = 0;
-
-   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "tries=%d", tryctr);
-   return rc;
-}
-
-
-/** Returns a parsed EDID record for the monitor on an I2C bus.
- *
- * @param fd      file descriptor for open /dev/i2c-n
- * @param edid_ptr_loc where to return pointer to newly allocated #Parsed_Edid,
- *                     or NULL if error
- * @return status code
- */
-Status_Errno_DDC
-i2c_get_parsed_edid_by_fd(int fd, Parsed_Edid ** edid_ptr_loc)
-{
-   bool debug  = false;
-   DBGTRC_STARTING(debug, TRACE_GROUP, "fd=%d, filename=%s", fd, filename_for_fd_t(fd));
-   Parsed_Edid * edid = NULL;
-   Buffer * rawedidbuf = buffer_new(EDID_BUFFER_SIZE, NULL);
-
-   Status_Errno_DDC rc = i2c_get_raw_edid_by_fd(fd, rawedidbuf);
-   if (rc == 0) {
-      edid = create_parsed_edid2(rawedidbuf->bytes, "I2C");
-      if (debug) {
-         if (edid)
-            report_parsed_edid(edid, false /* verbose */, 0);
-         else
-            DBGMSG("create_parsed_edid() returned NULL");
-      }
-      if (!edid)
-         rc = DDCRC_INVALID_EDID;
-   }
-
-   buffer_free(rawedidbuf, NULL);
-
-   *edid_ptr_loc = edid;
-   if (edid)
-      DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "*edid_ptr_loc = %p -> ...%s",
-                                 edid, hexstring3_t(edid->bytes+124, 4, "", 1, false));
-   else
-      DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "");
-
-   return rc;
-}
-
-
 //
 // I2C Bus Inspection - Fill in and report Bus_Info
 //
@@ -479,15 +313,17 @@ i2c_detect_x37(int fd) {
    // regard either a successful write() or a read() as indication slave address is valid
    Byte    writebuf = {0x00};
 
-   rc = i2c_ioctl_writer(fd, 0x37, 1, &writebuf);
+   rc = invoke_i2c_writer(fd, 0x37, 1, &writebuf);
+   // rc = i2c_ioctl_writer(fd, 0x37, 1, &writebuf);
    // rc = 6; // for testing
    DBGTRC_NOPREFIX(debug, TRACE_GROUP,
-                   "i2c_ioctl_writer() for slave address x37 returned %s", psc_name_code(rc));
+                   "invoke_i2c_writer() for slave address x37 returned %s", psc_name_code(rc));
    if (rc != 0) {
       Byte    readbuf[4];  //  4 byte buffer
-      rc = i2c_ioctl_reader(fd, 0x37, false, 4, readbuf);
+      rc = invoke_i2c_reader(fd, 0x37, false, 4, readbuf);
+      //rc = i2c_ioctl_reader(fd, 0x37, false, 4, readbuf);
       DBGTRC_NOPREFIX(debug, TRACE_GROUP,
-                      "i2c_ioctl_reader() for slave address x37 returned %s", psc_name_code(rc));
+                      "invoke_i2c_reader() for slave address x37 returned %s", psc_name_code(rc));
    }
    DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc,"");
    return rc;
@@ -517,6 +353,7 @@ void i2c_check_bus(I2C_Bus_Info * bus_info) {
       DBGMSF(debug, "Probing");
       bus_info->flags |= I2C_BUS_PROBED;
       bus_info->driver = get_driver_for_busno(bus_info->busno);
+      DBGMSF(debug, "Calling i2c_open_bus..");
       int fd = i2c_open_bus(bus_info->busno, CALLOPT_ERR_MSG);
       if (fd >= 0) {
           DBGMSF(debug, "Opened bus /dev/i2c-%d", bus_info->busno);
@@ -546,6 +383,8 @@ void i2c_check_bus(I2C_Bus_Info * bus_info) {
           }
           else if (ddcrc == -EBUSY)
              bus_info->flags |= I2C_BUS_BUSY;
+
+          DBGMSF(debug, "Closing bus...");
           i2c_close_bus(fd, CALLOPT_ERR_MSG);
       }
       else {
@@ -556,7 +395,7 @@ void i2c_check_bus(I2C_Bus_Info * bus_info) {
    // DBGTRC_DONE(debug, TRACE_GROUP, "flags=0x%04x, bus info:", bus_info->flags );
    if (debug || IS_TRACING() ) {
       char * sflags = interpret_i2c_bus_flags(bus_info->flags);
-      DBGTRC_DONE(true, TRACE_GROUP, "flags = 0x%04x = %s", bus_info->flags, sflags);
+      DBGTRC_DONE(true, TRACE_GROUP, "flags = 0x%08x = %s", bus_info->flags, sflags);
       // DBGTRC_NOPREFIX(true, TRACE_GROUP, "flags = %s", interpret_i2c_bus_flags_t(bus_info->flags));
       free(sflags);
       DBGTRC_NOPREFIX(true, TRACE_GROUP, "bus_info:");
@@ -575,6 +414,8 @@ void i2c_free_bus_info(I2C_Bus_Info * bus_info) {
             free_parsed_edid(bus_info->edid);
          if (bus_info->driver)
             free(bus_info->driver);
+         if (bus_info->drm_connector_name)
+            free(bus_info->drm_connector_name);
          bus_info->marker[3] = 'x';
          free(bus_info);
       }
@@ -597,7 +438,7 @@ void i2c_gdestroy_bus_info(gpointer data) {
  *  \param   depth       logical indentation depth
  *
  *  \remark
- *  Although this is a debug type report, it is called by used (indirectly) by the
+ *  Although this is a debug type report, it is called (indirectly) by the
  *  ENVIRONMENT command.
  */
 void i2c_dbgrpt_bus_info(I2C_Bus_Info * bus_info, int depth) {
@@ -621,6 +462,7 @@ void i2c_dbgrpt_bus_info(I2C_Bus_Info * bus_info, int depth) {
       rpt_vstring(depth, "Address 0x50 present:    %s", sbool(bus_info->flags & I2C_BUS_ADDR_0X50));
       rpt_vstring(depth, "Device busy:             %s", sbool(bus_info->flags & I2C_BUS_BUSY));
       rpt_vstring(depth, "errno for open:          %d", bus_info->open_errno);
+      rpt_vstring(depth, "drm_connector_name:      %s", bus_info->drm_connector_name);
       // not useful and clutters the output
       // i2c_report_functionality_flags(bus_info->functionality, /* maxline */ 90, depth);
       if ( bus_info->flags & I2C_BUS_ADDR_0X50) {
@@ -652,7 +494,7 @@ void i2c_dbgrpt_bus_info(I2C_Bus_Info * bus_info, int depth) {
  */
 void i2c_report_active_display(I2C_Bus_Info * businfo, int depth) {
    bool debug = false;
-   DBGMSF(debug, "Starting.  businfo=%p", businfo);
+   DBGTRC_STARTING(debug, TRACE_GROUP, "businfo=%p", businfo);
    assert(businfo);
 
    int d1 = depth+1;
@@ -660,12 +502,30 @@ void i2c_report_active_display(I2C_Bus_Info * businfo, int depth) {
    if (output_level >= DDCA_OL_NORMAL)
       rpt_vstring(depth, "I2C bus:  /dev/"I2C"-%d", businfo->busno);
    // will work for amdgpu, maybe others
+
+   businfo->drm_connector_found_by = DRM_CONNECTOR_NOT_FOUND;
    Sys_Drm_Connector * drm_connector = find_sys_drm_connector_by_busno(businfo->busno);
-   if (!drm_connector && businfo->edid)
+   if (drm_connector) {
+      businfo->drm_connector_found_by = DRM_CONNECTOR_FOUND_BY_BUSNO;
+      businfo->drm_connector_name = strdup(drm_connector->connector_name);
+   }
+   else if (businfo->edid) {
       drm_connector = find_sys_drm_connector_by_edid(businfo->edid->bytes);
+      if (drm_connector) {
+         businfo->drm_connector_name = strdup(drm_connector->connector_name);
+         businfo->drm_connector_found_by = DRM_CONNECTOR_FOUND_BY_EDID;
+      }
+   }
+   businfo->flags |= I2C_BUS_DRM_CONNECTOR_CHECKED;
+
    int title_width = (output_level >= DDCA_OL_VERBOSE) ? 36 : 25;
    if (drm_connector && output_level >= DDCA_OL_NORMAL)
-      rpt_vstring((output_level >= DDCA_OL_VERBOSE) ? d1 : depth, "%-*s%s", title_width, "DRM connector:", drm_connector->connector_name);
+      rpt_vstring((output_level >= DDCA_OL_VERBOSE) ? d1 : depth,
+                          "%-*s%s", title_width, "DRM connector:",
+                          (businfo->drm_connector_name)
+                               ? businfo->drm_connector_name
+                               : "Not found"
+                 );
 
    // 08/2018 Disable.
    // Test for DDC communication is now done more sophisticatedly at the DDC level
@@ -725,7 +585,7 @@ void i2c_report_active_display(I2C_Bus_Info * businfo, int depth) {
                            (output_level >= DDCA_OL_VERBOSE),
                            depth);
    }
-   DBGMSF(debug, "Done.");
+   DBGTRC_DONE(debug, TRACE_GROUP, "");
 }
 
 
@@ -894,7 +754,6 @@ I2C_Bus_Info * i2c_detect_single_bus(int busno) {
 }
 
 
-
 //
 // Bus_Info retrieval
 //
@@ -1058,19 +917,16 @@ int i2c_dbgrpt_buses(bool report_all, int depth) {
 static void init_i2c_bus_core_func_name_table() {
    RTTI_ADD_FUNC(i2c_open_bus);
    RTTI_ADD_FUNC(i2c_close_bus);
-   RTTI_ADD_FUNC(i2c_get_edid_bytes_using_i2c_layer);
    RTTI_ADD_FUNC(i2c_detect_buses);
    RTTI_ADD_FUNC(i2c_detect_single_bus);
    RTTI_ADD_FUNC(i2c_check_bus);
    RTTI_ADD_FUNC(i2c_detect_x37);
-   RTTI_ADD_FUNC(i2c_get_raw_edid_by_fd);
-   RTTI_ADD_FUNC(i2c_get_parsed_edid_by_fd);
+   RTTI_ADD_FUNC(i2c_report_active_display);
 }
 
 
 void init_i2c_bus_core() {
    init_i2c_bus_core_func_name_table();
-   init_i2c_execute_func_name_table();
    open_failures_reported = EMPTY_BIT_SET_256;
 }
 
