@@ -24,10 +24,6 @@
 #include "base/status_code_mgt.h"
 
 
-extern bool EDID_Read_Bytewise;
-extern bool EDID_Write_Before_Read;
-extern int  EDID_Read_Size;
-
 /** \def I2C_BUS_MAX maximum number of i2c buses this code supports */
 #define I2C_BUS_MAX 32
 
@@ -37,16 +33,11 @@ extern int  EDID_Read_Size;
 // shared with i2c_bus_selector.c
 extern GPtrArray * i2c_buses;
 
+// shared with i2c_bus_selector.c
+extern GPtrArray * i2c_buses;
+
 extern bool i2c_force_bus;
 
-// Basic I2C bus operations
-int           i2c_open_bus(int busno, Call_Options callopts);
-Status_Errno  i2c_close_bus(int fd, Call_Options callopts);
-
-// EDID inspection
-Status_Errno_DDC i2c_get_raw_edid_by_fd(int fd, Buffer * rawedid);
-Status_Errno_DDC i2c_get_parsed_edid_by_fd(int fd, Parsed_Edid ** edid_ptr_loc);
-
 // Retrieve and inspect bus information
 
 // Keep interpret_i2c_bus_flags() in sync with these definitions
@@ -62,6 +53,13 @@ Status_Errno_DDC i2c_get_parsed_edid_by_fd(int fd, Parsed_Edid ** edid_ptr_loc);
 #define I2C_BUS_HAS_VALID_NAME     0x0400
 #define I2C_BUS_BUSY               0x0200      ///< for possible future use
 #define I2C_BUS_SYSFS_EDID         0x0100
+#define I2C_BUS_DRM_CONNECTOR_CHECKED 0x8000
+
+typedef enum {
+   DRM_CONNECTOR_NOT_FOUND      = 0,
+   DRM_CONNECTOR_FOUND_BY_BUSNO = 1,
+   DRM_CONNECTOR_FOUND_BY_EDID  = 2
+} Drm_Connector_Found_By;
 
 #define I2C_BUS_INFO_MARKER "BINF"
 /** Information about one I2C bus */
@@ -74,32 +72,38 @@ struct {
    uint16_t         flags;              ///< I2C_BUS_* flags
    char *           driver;             ///< driver name
    int              open_errno;         ///< errno if open fails (!I2C_BUS_ACCESSIBLE)
+   char *           drm_connector_name; ///< from /sys
+   Drm_Connector_Found_By
+                    drm_connector_found_by;
 } I2C_Bus_Info;
 
-void i2c_dbgrpt_bus_info(I2C_Bus_Info * bus_info, int depth);
-void i2c_report_active_display(I2C_Bus_Info * businfo, int depth);
+// Basic I2C bus operations
+int              i2c_open_bus(int busno, Call_Options callopts);
+Status_Errno     i2c_close_bus(int fd, Call_Options callopts);
 
-// Simple bus detection, no side effects
-bool i2c_device_exists(int busno);
-int  i2c_device_count();           // simple /dev/i2c-n count, no side effects
+void             i2c_dbgrpt_bus_info(I2C_Bus_Info * bus_info, int depth);
+void             i2c_report_active_display(I2C_Bus_Info * businfo, int depth);
+
+bool             i2c_device_exists(int busno); // Simple bus detection, no side effects
+int              i2c_device_count();           // simple /dev/i2c-n count, no side effects
 Byte_Value_Array get_i2c_devices_by_existence_test();
-void add_open_failures_reported(Bit_Set_256 failures);
-void include_open_failures_reported(int busno);
+
+void             add_open_failures_reported(Bit_Set_256 failures);
+void             include_open_failures_reported(int busno);
 
 // Bus inventory - detect and probe buses
-int i2c_detect_buses();            // creates internal array of Bus_Info for I2C buses
-void i2c_discard_buses();
-I2C_Bus_Info * i2c_detect_single_bus(int busno);
-void i2c_free_bus_info(I2C_Bus_Info * bus_info);
+int              i2c_detect_buses();            // creates internal array of Bus_Info for I2C buses
+void             i2c_discard_buses();
+I2C_Bus_Info *   i2c_detect_single_bus(int busno);
+void             i2c_free_bus_info(I2C_Bus_Info * bus_info);
 
 // Simple Bus_Info retrieval
-I2C_Bus_Info * i2c_get_bus_info_by_index(uint busndx);
-I2C_Bus_Info * i2c_find_bus_info_by_busno(int busno);
-
+I2C_Bus_Info *   i2c_get_bus_info_by_index(uint busndx);
+I2C_Bus_Info *   i2c_find_bus_info_by_busno(int busno);
 
 // Reports all detected i2c buses:
-int  i2c_dbgrpt_buses(bool report_all, int depth);
+int              i2c_dbgrpt_buses(bool report_all, int depth);
 
-void init_i2c_bus_core();
+void             init_i2c_bus_core();
 
 #endif /* I2C_BUS_CORE_H_ */
