@@ -12,6 +12,12 @@
 #include "util/coredefs.h"
 #include "base/status_code_mgt.h"
 
+// Controls whether function #i2c_set_addr() retries from EBUSY error by
+// changing ioctl op I2C_SLAVE to op I2C_SLAVE_FORCE.
+extern bool i2c_forceable_slave_addr_flag;
+
+Status_Errno i2c_set_addr(int fd, int addr);
+
 /** Function template for I2C write function */
 typedef Status_Errno_DDC (*I2C_Writer)(
       int    fd,
@@ -27,6 +33,19 @@ typedef Status_Errno_DDC (*I2C_Reader)(
       int    bytect,
       Byte * readbuf);
 
+Status_Errno_DDC i2c_fileio_writer(
+      int    fd,
+      Byte   slave_address,
+      int    bytect,
+      Byte * pbytes);
+
+Status_Errno_DDC i2c_fileio_reader (
+      int    fd,
+      Byte   slave_address,
+      bool   read_bytewise,
+      int    bytect,
+      Byte * readbuf);
+
 Status_Errno_DDC i2c_ioctl_writer(
       int    fd,
       Byte   slave_address,
@@ -40,6 +59,6 @@ Status_Errno_DDC i2c_ioctl_reader(
       int    bytect,
       Byte * readbuf);
 
-void init_i2c_execute_func_name_table();
+void init_i2c_execute();
 
 #endif /* I2C_EXECUTE_H_ */
