@@ -9,6 +9,7 @@
 #include "config.h"
 
 #include <assert.h>
+#include <base/base_services.h>
 #include <errno.h>
 #include <glib-2.0/glib.h>
 #include <signal.h>
@@ -24,12 +25,12 @@
 #include "util/sysfs_filter_functions.h"
 #include "util/xdg_util.h"
 
-#include "base/base_init.h"
 #include "base/build_info.h"
 #include "base/core.h"
 #include "base/core_per_thread_settings.h"
 #include "base/parms.h"
 #include "base/per_thread_data.h"
+#include "base/rtti.h"
 #include "base/thread_retry_data.h"
 #include "base/thread_sleep_data.h"
 #include "base/tuned_sleep.h"
@@ -37,7 +38,8 @@
 #include "cmdline/cmd_parser.h"
 #include "cmdline/parsed_cmd.h"
 
-// #include "i2c/i2c_bus_core.h"   // for testing watch_devices
+#include "i2c/i2c_bus_core.h"   // for testing watch_devices
+#include "i2c/i2c_execute.h"    // for i2c_set_addr()
 
 #include "ddc/ddc_common_init.h"
 #include "ddc/ddc_display_lock.h"
@@ -53,6 +55,12 @@
 #include "libmain/api_base_internal.h"
 #include "libmain/api_services_internal.h"
 
+//
+// Forward Declarations
+//
+
+void init_api_base();
+
 
 //
 // Precondition Failure
@@ -156,7 +164,6 @@ char * get_library_filename() {
 // Initialization
 //
 
-
 static
 Parsed_Cmd * get_parsed_libmain_config() {
    bool debug = false;
@@ -195,15 +202,18 @@ Parsed_Cmd * get_parsed_libmain_config() {
       ntsa_show(new_argv);
 
    if (errmsgs->len > 0) {
-      f0printf(ferr(), "Errors reading libddcutil configuration file %s:\n", config_fn);
+      f0printf(ferr(),    "Error(s) reading libddcutil configuration from file %s:\n", config_fn);
+      SYSLOG(LOG_WARNING, "Error(s) reading libddcutil configuration from file %s:",   config_fn);
       for (int ndx = 0; ndx < errmsgs->len; ndx++) {
-         f0printf(fout(), "   %s\n", (char*) g_ptr_array_index(errmsgs, ndx));
+         f0printf(fout(),     "   %s\n", (char*) g_ptr_array_index(errmsgs, ndx));
+         SYSLOG(LOG_WARNING,  "   %s",   (char*) g_ptr_array_index(errmsgs, ndx));
       }
    }
    g_ptr_array_free(errmsgs, true);
-   if (untokenized_option_string && strlen(untokenized_option_string) > 0)
-      fprintf(fout(), "Applying libddcutil options from %s: %s\n", config_fn,
-            untokenized_option_string);
+   if (untokenized_option_string && strlen(untokenized_option_string) > 0) {
+      fprintf(fout(), "Applying libddcutil options from %s: %s\n", config_fn, untokenized_option_string);
+      SYSLOG(LOG_INFO,"Applying libddcutil options from %s: %s",   config_fn, untokenized_option_string);
+   }
 
    // Continue even if config file errors
    // if (apply_config_rc < 0)
@@ -214,16 +224,14 @@ Parsed_Cmd * get_parsed_libmain_config() {
    DBGF(debug, "Calling parse_command()");
    parsed_cmd = parse_command(new_argc, new_argv, MODE_LIBDDCUTIL);
    if (!parsed_cmd) {
-      syslog(LOG_WARNING, "Ignoring invalid configuration file options: %s",
-            untokenized_option_string);
-      fprintf(ferr(), "Ignoring invalid configuration file options: %s\n",
-                      untokenized_option_string);
+      SYSLOG(LOG_WARNING, "Ignoring invalid configuration file option string: %s",  untokenized_option_string);
+      fprintf(ferr(),     "Ignoring invalid configuration file option string: %s\n",untokenized_option_string);
       DBGF(debug, "Retrying parse_command() with no options");
       parsed_cmd = parse_command(1, cmd_name_array, MODE_LIBDDCUTIL);
    }
    if (debug)
       dbgrpt_parsed_cmd(parsed_cmd, 1);
-   DBGF(debug, "Calling ntsa_free(cmd_name_array=%p", cmd_name_array);
+   // DBGF(debug, "Calling ntsa_free(cmd_name_array=%p", cmd_name_array);
    ntsa_free(cmd_name_array, false);
    ntsa_free(new_argv, true);
    free(untokenized_option_string);
@@ -238,7 +246,7 @@ Parsed_Cmd * get_parsed_libmain_config() {
 void done() {
    printf("(%s) Starting\n", __func__);
    _ddca_terminate();
-   syslog(LOG_INFO, "(%s) executing done()", __func__);
+   SYSLOG(LOG_INFO, "(%s) executing done()", __func__);
    printf("(%s) Done.\n", __func__);
 }
 
@@ -256,6 +264,8 @@ void atexit_func() {
 static FILE * flog = NULL;
 
 bool library_initialized = false;
+DDCA_Stats_Type requested_stats = 0;
+bool per_thread_stats = false;
 
 /** Initializes the ddcutil library module.
  *
@@ -273,12 +283,15 @@ _ddca_init(void) {
    if (debug)
       printf("(%s) Starting. library_initialized=%s\n", __func__, sbool(library_initialized));
    if (!library_initialized) {
+#ifdef ENABLE_SYSLOG
       openlog("libddcutil", LOG_CONS|LOG_PID, LOG_USER);
       syslog(LOG_INFO, "Initializing.  ddcutil version %s", get_full_ddcutil_version());
+#endif
 #ifdef TESTING_CLEANUP
       // signal(SIGTERM, dummy_sigterm_handler);
       // atexit(atexit_func);  // TESTING CLAEANUP
 #endif
+      init_api_base();
       init_base_services();
       Parsed_Cmd* parsed_cmd = get_parsed_libmain_config();
       init_tracing(parsed_cmd);
@@ -289,7 +302,7 @@ _ddca_init(void) {
                 : strdup(parsed_cmd->library_trace_file);
          if (debug)
             printf("(%s) Setting trace destination %s\n", __func__, trace_file);
-         syslog(LOG_INFO, "Trace destination: %s", trace_file);
+         SYSLOG(LOG_INFO, "Trace destination: %s", trace_file);
 
          fopen_mkdir(trace_file, "a", stderr, &flog);
 
@@ -313,10 +326,14 @@ _ddca_init(void) {
          else {
             fprintf(stderr, "Error opening libddcutil trace file %s: %s\n",
                             trace_file, strerror(errno));
+            SYSLOG(LOG_WARNING, "Error opening libddcutil trace file %s: %s",
+                            trace_file, strerror(errno));
          }
          free(trace_file);
       }
 
+      requested_stats = parsed_cmd->stats_types;
+      per_thread_stats = parsed_cmd->flags & CMD_FLAG_PER_THREAD_STATS;
       init_api_services();
       submaster_initializer(parsed_cmd);
       free_parsed_cmd(parsed_cmd);
@@ -341,12 +358,16 @@ _ddca_init(void) {
 #endif
 
       DBGTRC_DONE(debug, DDCA_TRC_API, "library initialization executed");
-      syslog(LOG_INFO, "Library initialization complete.");
+      SYSLOG(LOG_INFO, "Library initialization complete.");
    }
    else {
       DBGTRC_DONE (debug, DDCA_TRC_API, "library was already initialized");
+      SYSLOG(LOG_INFO, "Library was already initialized.");
    }
    // TRACED_ASSERT(1==5); for testing
+
+   // Not really necessary, but seeing errno == 2 has perplexed some library users
+   errno = 0;
 }
 
 
@@ -363,6 +384,8 @@ _ddca_terminate(void) {
       if (debug)
          dbgrpt_distinct_display_descriptors(2);
       ddc_discard_detected_displays();
+      if (requested_stats)
+         ddc_report_stats_main(requested_stats, per_thread_stats, 0);
       release_base_services();
       ddc_stop_watch_displays();
       free_regex_hash_table();
@@ -374,7 +397,7 @@ _ddca_terminate(void) {
    else {
       DBGTRC_DONE(debug, DDCA_TRC_API, "library was already terminated");   // should be impossible
    }
-   syslog(LOG_INFO, "Terminating.");
+   SYSLOG(LOG_INFO, "Terminating.");
    closelog();
 }
 
@@ -702,15 +725,28 @@ ddca_is_sleep_suppression_enabled() {
 double
 ddca_set_default_sleep_multiplier(double multiplier)
 {
-   double result = tsd_get_default_sleep_multiplier_factor();
-   tsd_set_default_sleep_multiplier_factor(multiplier);
-   return result;
+   bool debug = false;
+   DBGTRC_STARTING(debug, DDCA_TRC_API, "Setting multiplier = %6.3f", multiplier);
+
+   double old_value = -1.0;
+   if (multiplier >= 0.0 && multiplier <= 10.0) {
+      old_value = tsd_get_default_sleep_multiplier_factor();
+      tsd_set_default_sleep_multiplier_factor(multiplier);
+    }
+
+   DBGTRC_DONE(debug, DDCA_TRC_API, "Returning: %6.3f", old_value);
+   return old_value;
 }
 
+
 double
 ddca_get_default_sleep_multiplier()
 {
-   return tsd_get_default_sleep_multiplier_factor();
+   bool debug = false;
+   DBGTRC_STARTING(debug, DDCA_TRC_API, "");
+   double result = tsd_get_default_sleep_multiplier_factor();
+   DBGTRC(debug, DDCA_TRC_API, "Returning %6.3f", result);
+   return result;
 }
 
 void
@@ -730,21 +766,26 @@ ddca_get_global_sleep_multiplier()
 double
 ddca_set_sleep_multiplier(double multiplier)
 {
-   // bool debug = false;
-   double result = tsd_get_sleep_multiplier_factor();
-   // DBGMSF(debug, "Setting %5.2f", multiplier);
-   tsd_set_sleep_multiplier_factor(multiplier);
-   // DBGMSF(debug, "Done");
-   return result;
+   bool debug = false;
+   DBGTRC_STARTING(debug, DDCA_TRC_API, "Setting multiplier = %6.3f", multiplier);
+
+   double old_value = -1.0;
+   if (multiplier >= 0.0 && multiplier <= 10.0) {
+      old_value = tsd_get_sleep_multiplier_factor();
+      tsd_set_sleep_multiplier_factor(multiplier);
+   }
+
+   DBGTRC_DONE(debug, DDCA_TRC_API, "Returning: %6.3f", old_value);
+   return old_value;
 }
 
 double
 ddca_get_sleep_multiplier()
 {
-   // bool debug = false;
-   // DBGMSF(debug, "Starting");
+   bool debug = false;
+   DBGTRC(debug, DDCA_TRC_API, "");
    double result = tsd_get_sleep_multiplier_factor();
-   // DBGMSF(debug, "Returning %5.2f", result);
+   DBGTRC(debug, DDCA_TRC_API, "Returning %6.3f", result);
    return result;
 }
 
@@ -774,7 +815,7 @@ ddca_set_timeout_millis(
 }
 #endif
 
-
+#ifdef FUTURE
 bool
 ddca_enable_force_slave_address(bool onoff) {
    return false;
@@ -785,6 +826,22 @@ bool
 ddca_is_force_slave_address_enabled(void) {
    return false;
 }
+#endif
+
+
+bool
+ddca_enable_force_slave_address(bool onoff) {
+   bool old = i2c_forceable_slave_addr_flag;
+   i2c_forceable_slave_addr_flag = onoff;
+   return old;
+}
+
+
+bool
+ddca_is_force_slave_address_enabled(void) {
+   return i2c_forceable_slave_addr_flag;
+}
+
 
 
 //
@@ -886,3 +943,8 @@ ddca_show_stats(
 }
 
 
+void init_api_base() {
+   RTTI_ADD_FUNC(ddca_set_sleep_multiplier);
+   RTTI_ADD_FUNC(ddca_set_default_sleep_multiplier);
+}
+
