@@ -4,7 +4,7 @@
  *  and of otherwise unpublished and archived functions.
  */
 
-// Copyright (C) 2015-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2015-2021 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef API_FEATURE_ACCESS_INTERNAL_H_
@@ -78,40 +78,4 @@ ddca_format_any_vcp_value(
       char **                 formatted_value_loc);
 
 
-//
-// Experimental - Not for public use
-//
-// Used in exploratory Python APIs
-//
-
-DDCA_Status
-ddca_start_get_any_vcp_value(
-      DDCA_Display_Handle         ddca_dh,
-      DDCA_Vcp_Feature_Code       feature_code,
-      DDCA_Vcp_Value_Type         call_type,
-      DDCA_Notification_Func      callback_func);
-
-
-// UNIMPLEMENTED
-/** Registers a callback function to call when a VCP value changes */
-DDCA_Status
-ddca_register_callback(
-      DDCA_Notification_Func func,
-      uint8_t                callback_options);   // type is a placeholder
-
-DDCA_Status
-ddca_pass_callback(
-      Simple_Callback_Func  func,
-      int                   parm
-      );
-
-// unimplemeted
-DDCA_Status
-ddca_queue_get_non_table_vcp_value(
-      DDCA_Display_Handle      ddca_dh,
-      DDCA_Vcp_Feature_Code    feature_code
-);
-
-
-
 #endif /* API_FEATURE_ACCESS_INTERNAL_H_ */
