@@ -17,7 +17,7 @@
 #include "base/core.h"
 #include "base/displays.h"
 #include "base/feature_lists.h"
-#include "base/feature_sets.h"
+#include "base/feature_set_ref.h"
 
 #include "vcp/vcp_feature_codes.h"
 #include "vcp/vcp_feature_set.h"
@@ -170,6 +170,49 @@ bye:
 #endif
 
 
+
+DDCA_Feature_List
+feature_list_from_dyn_feature_set(Dyn_Feature_Set * fset)
+{
+   bool debug = false;
+   if (debug || IS_TRACING()) {
+      DBGMSG("Starting. feature_set = %p -> %s", (void*)fset, feature_subset_name(fset->subset));
+      // show_backtrace(2);
+      dbgrpt_dyn_feature_set(fset, false, 1);
+   }
+
+   DDCA_Feature_List vcplist = {{0}};
+   assert( fset && memcmp(fset->marker, DYN_FEATURE_SET_MARKER, 4) == 0);
+   int ndx = 0;
+   for (; ndx < fset->members_dfm->len; ndx++) {
+      Display_Feature_Metadata * vcp_entry = g_ptr_array_index(fset->members_dfm,ndx);
+
+      feature_list_add(&vcplist, vcp_entry->feature_code);
+
+#ifdef OLD
+      uint8_t vcp_code = vcp_entry->feature_code;
+      // DBGMSG("Setting feature: 0x%02x", vcp_code);
+      int flagndx   = vcp_code >> 3;
+      int shiftct   = vcp_code & 0x07;
+      Byte flagbit  = 0x01 << shiftct;
+      // printf("(%s) vcp_code=0x%02x, flagndx=%d, shiftct=%d, flagbit=0x%02x\n",
+      //        __func__, vcp_code, flagndx, shiftct, flagbit);
+      vcplist.bytes[flagndx] |= flagbit;
+      // uint8_t bval = vcplist.bytes[flagndx];
+      // printf("(%s) vcplist.bytes[%d] = 0x%02x\n",  __func__, flagndx, bval);
+#endif
+   }
+
+   if (debug || IS_TRACING()) {
+      DBGMSG("Returning: %s", feature_list_string(&vcplist, "", ","));
+      // rpt_hex_dump(vcplist.bytes, 32, 1);
+   }
+
+   return vcplist;
+}
+
+
+
 DDCA_Status
 ddca_get_feature_list_by_dref(
       DDCA_Feature_Subset_Id  feature_set_id,
@@ -234,7 +277,7 @@ ddca_get_feature_list_by_dref(
                Feature_Set_Flags flags = 0x00;
                if (!include_table_features)
                   flags |= FSF_NOTABLE;
-               Dyn_Feature_Set * fset = dyn_create_feature_set2(subset, dref, flags);
+               Dyn_Feature_Set * fset = dyn_create_feature_set(subset, dref, flags);
                // VCP_Feature_Set fset = create_feature_set(subset, vspec, !include_table_features);
 
                // TODO: function variant that takes result location as a parm, avoid memcpy
@@ -243,7 +286,7 @@ ddca_get_feature_list_by_dref(
                dyn_free_feature_set(fset);
          }
    );
-   DBGTRC_RETURNING(debug, TRACE_GROUP, psc, "feature_set_id=%d=0x%08x=%s, subset=%d=%s",
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, psc, "feature_set_id=%d=0x%08x=%s, subset=%d=%s",
          feature_set_id, feature_set_id, ddca_feature_list_id_name(feature_set_id),
          subset, feature_subset_name(subset));
    DBGTRC_NOPREFIX(debug, TRACE_GROUP,
@@ -534,7 +577,7 @@ ddca_get_feature_metadata_by_dref(
                *metadata_loc = external_metadata;
          }
    );
-   DBGTRC_RETURNING(debug, TRACE_GROUP, psc, "");
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, psc, "");
    ASSERT_IFF(psc==0, *metadata_loc);
    return psc;
 }
@@ -572,8 +615,8 @@ ddca_get_feature_metadata_by_dh(
                }
                *metadata_loc = external_metadata;
                ASSERT_IFF(psc == 0, *metadata_loc);
-               DBGTRC_RETURNING(debug, DDCA_TRC_API, psc,
-                                        "ddca_dh=%p->%s", ddca_dh, dh_repr_t(ddca_dh));
+               DBGTRC_RET_DDCRC(debug, DDCA_TRC_API, psc,
+                                        "ddca_dh=%p->%s", ddca_dh, dh_repr(ddca_dh));
                 if (psc == 0 && debug) {
                    dbgrpt_ddca_feature_metadata(external_metadata, 5);
                 }
@@ -891,7 +934,7 @@ ddca_dfr_check_by_dref(DDCA_Display_Ref ddca_dref)
             }
       }
    );
-   DBGTRC_RETURNING(debug, TRACE_GROUP, psc, "");
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, psc, "");
    return psc;
 }
 
@@ -902,12 +945,12 @@ ddca_dfr_check_by_dh(DDCA_Display_Handle ddca_dh)
    DBGTRC_STARTING(debug, DDCA_TRC_API, "ddca_dh=%p", ddca_dh);
    WITH_VALIDATED_DH2(ddca_dh,
       {
-            DBGMSF(debug, "dref=%s", dh_repr_t(dh));
+            DBGMSF(debug, "dref=%s", dh_repr(dh));
 
             psc = ddca_dfr_check_by_dref(dh->dref);
 
             DBGTRC_DONE(debug, DDCA_TRC_API, "ddca_dh=%p->%s. Returning: %s(%d)",
-                   ddca_dh, dh_repr_t(ddca_dh), ddca_rc_name(psc), psc);
+                   ddca_dh, dh_repr(ddca_dh), ddca_rc_name(psc), psc);
       }
    );
 }
