@@ -1,7 +1,7 @@
 /** @file hiddev_util.c
  */
 
-// Copyright (C) 2016-2020 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2016-2021 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 
@@ -11,7 +11,6 @@
 #include <assert.h>
 #include <dirent.h>
 #include <errno.h>
-// #include <glib.h>
 #include <glib-2.0/glib.h>
 #include <libudev.h>
 #include <linux/hiddev.h>
@@ -20,10 +19,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <strings.h>
+#include <string.h>
 #include <sys/ioctl.h>
 #include <unistd.h>
-// #include <wchar.h>
 
 #include "util/coredefs.h"
 #include "util/file_util.h"
@@ -37,7 +35,6 @@
 #include "usb_util/hiddev_reports.h"
 #include "usb_util/hiddev_util.h"
 
-#include "base/core.h"
 
 static const char* report_type_id_table[] = {
       "invalid value",
@@ -109,7 +106,7 @@ get_hiddev_device_names_using_udev() {
    if (debug) printf("(%s) Starting...\n", __func__);
 
    GPtrArray * dev_names = g_ptr_array_sized_new(10);
-   g_ptr_array_set_free_func(dev_names, free);
+   g_ptr_array_set_free_func(dev_names, g_free);
 
    struct udev *udev;
    struct udev_enumerate *enumerate;
@@ -734,9 +731,11 @@ get_multibyte_value_by_uref_multi(
    int      rc;
    Buffer * result = NULL;
 
+#ifndef NDEBUG
    __u32 report_type = uref_multi->uref.report_type;
    assert(report_type == HID_REPORT_TYPE_FEATURE ||
           report_type == HID_REPORT_TYPE_INPUT);   // *** CG19 ***
+#endif
 
    rc = ioctl(fd, HIDIOCGUSAGES, uref_multi);  // Fills in usage value
    if (rc != 0) {
@@ -754,9 +753,9 @@ get_multibyte_value_by_uref_multi(
 
 bye:
    if (debug) {
-      DBGMSG("Returning: %p", result);
+      printf("Returning: %p\n", result);
       if (result) {
-         dbgrpt_buffer(result, 1);
+         buffer_dump(result);
       }
    }
    return result;
