@@ -10,7 +10,7 @@
  *  to **ddcutil** are interpreted.
  */
 
-// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2023 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -326,7 +326,8 @@ void report_parsed_edid_base(
 {
    bool debug = false;
    if (debug)
-      printf("(%s) Starting. edid=%p", __func__, (void*)edid);
+      printf("(%s) Starting. edid=%p, verbose_synopsis=%s, show_raw=%s\n",
+             __func__, (void*)edid, SBOOL(verbose_synopsis), sbool(show_raw));
 
    int d1 = depth+1;
    int d2 = depth+2;
@@ -416,7 +417,9 @@ void report_parsed_edid_base(
             rpt_vstring(d2, "DPMS suspend");
          if (edid->supported_features & 0x20)
             rpt_vstring(d2, "DPMS active-off");
-         Byte display_type = (edid->supported_features & 0x14) >> 3;     // bits 4-3
+         Byte display_type = (edid->supported_features & 0x18) >> 3;     // bits 4-3
+         // printf("(%s) supported_features = 0x%02x, display_type = 0x%02x=%d\n",
+         //       __func__, edid->supported_features, display_type, display_type);
          if (edid->video_input_definition & 0x80) {   // digital input
             switch(display_type) {
             case 0:
@@ -492,7 +495,12 @@ void report_parsed_edid_base(
  *  @param  depth      logical indentation depth
  */
 void report_parsed_edid(Parsed_Edid * edid, bool verbose, int depth) {
+   bool debug = false;
+   if (debug)
+      printf("(%s) Starting. verbose=%s\n", __func__, SBOOL(verbose));
    report_parsed_edid_base(edid, verbose, verbose, depth);
+   if (debug)
+      printf("(%s) Done.\n", __func__);
 }
 
 
