@@ -31,7 +31,7 @@
 
 
 // Validates a pointer to an #Error_Info, using asserts
-#define VALID_DDC_ERROR_PTR(ptr) \
+#define VALID_ERROR_INFO_PTR(ptr) \
    assert(ptr); \
    assert(memcmp(ptr->marker, ERROR_INFO_MARKER, 4) == 0);
 
@@ -59,7 +59,8 @@ static ErrInfo_Status_String errinfo_name_func =  NULL;
  *   \param   name_func  function returning the name of a status code
  *   \param   desc_func  function returning a description of a status code
  */
-void errinfo_init(
+void
+errinfo_init(
       ErrInfo_Status_String name_func,
       ErrInfo_Status_String desc_func)
 {
@@ -85,7 +86,7 @@ errinfo_free(Error_Info * erec){
       show_backtrace(2);
    }
    if (erec) {
-      VALID_DDC_ERROR_PTR(erec);
+      VALID_ERROR_INFO_PTR(erec);
 
       if (debug) {
          printf("(%s) Freeing exception: \n", __func__);
@@ -145,14 +146,13 @@ errinfo_free_with_report(
 
 static void ddc_error_free2(void * erec) {
    Error_Info* erec2 = (Error_Info *) erec;
-   VALID_DDC_ERROR_PTR(erec2);
+   VALID_ERROR_INFO_PTR(erec2);
    errinfo_free(erec2);
 }
 #endif
 
-
 //
-// Instance creation
+// Instance modification
 //
 
 /** Sets the status code in a existing #Error_Info instance.
@@ -162,32 +162,14 @@ static void ddc_error_free2(void * erec) {
  */
 void
 errinfo_set_status(Error_Info * erec, int code) {
-   VALID_DDC_ERROR_PTR(erec);
+   VALID_ERROR_INFO_PTR(erec);
    erec->status_code = code;
 }
 
-/** Sets the detail string in a existing #Error_Info instance.
- *
- *  \param  erec   pointer to instance
- *  \param  detail detail string
- */
-void
-errinfo_set_detail(
-      Error_Info *   erec,
-      char *         detail)
-{
-   VALID_DDC_ERROR_PTR(erec);
-   if (erec->detail) {
-      free(erec->detail);
-      erec->detail = NULL;
-   }
-   if (detail)
-      erec->detail = strdup(detail);
-}
 
 static void
 errinfo_set_detailv(
-      Error_Info *  erec,
+      Error_Info * erec,
       const char * detail,
       va_list      args)
 {
@@ -197,14 +179,26 @@ errinfo_set_detailv(
 }
 
 
-void errinfo_set_detail3(
-      Error_Info *   erec,
+/** Sets the detail string in a existing #Error_Info instance.
+ *  If there is already a detail string in the instance, it is replaced.
+ *
+ *  \param  erec   pointer to instance
+ *  \param  detail detail format string
+ *  \param  ...    arguments for format string
+ */
+void
+errinfo_set_detail(
+      Error_Info *  erec,
       const char *  detail_fmt,
       ...)
 {
+   VALID_ERROR_INFO_PTR(erec);
+   if (erec->detail) {
+      free(erec->detail);
+      erec->detail = NULL;
+   }
    va_list ap;
-      va_start(ap, detail_fmt);
-
+   va_start(ap, detail_fmt);
 
    errinfo_set_detailv(erec, detail_fmt, ap);
    va_end(ap);
@@ -222,8 +216,8 @@ errinfo_add_cause(
       Error_Info * cause)
 {
    // printf("(%s) cause=%p\n", __func__, cause);
-   VALID_DDC_ERROR_PTR(parent);
-   VALID_DDC_ERROR_PTR(cause);
+   VALID_ERROR_INFO_PTR(parent);
+   VALID_ERROR_INFO_PTR(cause);
 
    // printf("(%s) parent->cause_ct = %d, parent->max_causes = %d\n",
    //         __func__, parent->cause_ct, parent->max_causes);
@@ -266,6 +260,10 @@ errinfo_add_cause(
 }
 
 
+//
+// Instance creation
+//
+
 /** Creates a new #Error_Info instance with the specified status code,
  *  function name, and detail string.  The substitution values for the
  *  detail string are specified as an arg_list.
@@ -296,22 +294,6 @@ errinfo_newv(
 }
 
 
-/** Creates a new #Error_Info instance with the specified status code
- *  and function name.
- *
- *  \param  status_code  status code
- *  \param  func         name of function generating status code
- *  \return pointer to new instance
- */
-Error_Info *
-errinfo_new(
-      int          status_code,
-      const char * func)
-{
-   return errinfo_new2(status_code, func, NULL);
-}
-
-
 /** Creates a new #Error_Info instance with the specified status code,
  *  function name, and detail string.
  *
@@ -322,7 +304,7 @@ errinfo_new(
  *  \return pointer to new instance
  */
 Error_Info *
-errinfo_new2(
+errinfo_new(
       int            status_code,
       const char *   func,
       const char *   detail,
@@ -338,27 +320,7 @@ errinfo_new2(
 }
 
 
-#ifdef UNUSED
-/** Creates a new #Error_Info instance, including a reference to another
- *  instance that is the cause of the current error.
- *
- *  \param  code   status code
- *  \param  cause  pointer to another #Error_Info that is included as a cause
- *  \param  func   name of function creating new instance
- *  \return pointer to new instance
- */
-Error_Info * errinfo_new_with_cause(
-      int            code,
-      Error_Info *   cause,
-      const char *   func)
-{
-   return errinfo_new_with_cause2(code, cause, func, NULL);
-}
-#endif 
-
-
-static
-Error_Info *
+static Error_Info *
 errinfo_new_with_causev(
       int            status_code,
       Error_Info *   cause,
@@ -378,24 +340,12 @@ errinfo_new_with_causev(
  *  \param  status_code  status code
  *  \param  cause        pointer to another #Error_Info that is included as a cause
  *  \param  func         name of function creating new instance
- *  \param  detail       optional detail string
+ *  \param  detail_fmt   optional detail format string
+ *  \param  ...          optional arguments for detail_fmt
  *  \return pointer to new instance
  */
 Error_Info *
-errinfo_new_with_cause2(
-      int            status_code,
-      Error_Info *   cause,
-      const char *   func,
-      char *         detail)
-{
-   VALID_DDC_ERROR_PTR(cause);
-   Error_Info * erec = errinfo_new2(status_code, func, detail);
-   errinfo_add_cause(erec, cause);
-   return erec;
-}
-
-Error_Info *
-errinfo_new_with_cause3(
+errinfo_new_with_cause(
       int            status_code,
       Error_Info *   cause,
       const char *   func,
@@ -424,7 +374,7 @@ Error_Info * errinfo_new_chained(
       Error_Info * cause,
       const char * func)
 {
-   VALID_DDC_ERROR_PTR(cause);
+   VALID_ERROR_INFO_PTR(cause);
    Error_Info * erec = errinfo_new_with_cause(cause->status_code, cause, func);
    return erec;
 }
@@ -438,36 +388,12 @@ Error_Info * errinfo_new_chained(
  *  \param  causes          array of #Error_Info instances
  *  \param  cause_ct        number of causes
  *  \param  func            name of function creating the new #Error_Info
+ *  \param  detail          detail format string
+ *  \param  ...             optional arguments for detail format string
  *  \return pointer to new instance
  */
 Error_Info *
 errinfo_new_with_causes(
-      int             code,
-      Error_Info **   causes,
-      int             cause_ct,
-      const char *    func)
-{
-   return errinfo_new_with_causes2(code, causes, cause_ct, func, NULL);
-}
-
-Error_Info *
-errinfo_new_with_causes2(
-      int            status_code,
-      Error_Info **  causes,
-      int            cause_ct,
-      const char *   func,
-      char *         detail)
-{
-   Error_Info * result = errinfo_new2(status_code, func, detail);
-   for (int ndx = 0; ndx < cause_ct; ndx++) {
-      errinfo_add_cause(result, causes[ndx]);
-   }
-   return result;
-}
-
-
-Error_Info *
-errinfo_new_with_causes3(
       int            status_code,
       Error_Info **  causes,
       int            cause_ct,
@@ -525,7 +451,7 @@ Error_Info * errinfo_new_with_callee_status_codes(
 // Reporting
 //
 
-/** Status code description function to be used if none is set
+/** Status code description function to be used if none was set
  *  by #errinfo_init()
  *
  *  \param  code  status code
@@ -547,12 +473,11 @@ default_status_code_desc(int rc) {
 }
 
 
-
-GString *
+static GString *
 errinfo_array_summary_gs(
       struct error_info **  errors,    ///<  pointer to array of pointers to Error_Info
-      int                   error_ct,
-      GString *             gs)     ///<  number of causal errors
+      int                   error_ct,  ///<  number of causal errors
+      GString *             gs)        ///<  append result here
 {
       bool first = true;
 
@@ -613,7 +538,7 @@ errinfo_array_summary(
 }
 
 
-/** Returns a comma separated string of the status code names in the
+/** Returns a comma separated string of the names of the status codes in the
  *  causes of the specified #Error_Info.
  *  Multiple consecutive identical names are replaced with a
  *  single name and a parenthesized instance count.
@@ -638,10 +563,6 @@ errinfo_causes_string(Error_Info * erec) {
    // DBGMSF(debug, "Done.  Returning: |%s|", result);
    return result;
 
-
-
-
-
 #ifdef OLD
    GString * gs = g_string_new(NULL);
 
@@ -783,6 +704,7 @@ errinfo_report(Error_Info * erec, int depth) {
    // rpt_vstring(depth, "(%s) Done", __func__);
 }
 
+
 void
 errinfo_report_details(Error_Info * erec, int depth) {
    assert(erec);
@@ -819,7 +741,7 @@ char *
 errinfo_summary(Error_Info * erec) {
    if (!erec)
       return "NULL";
-   VALID_DDC_ERROR_PTR(erec);
+   VALID_ERROR_INFO_PTR(erec);
 
    static GPrivate  esumm_key     = G_PRIVATE_INIT(g_free);
    static GPrivate  esumm_len_key = G_PRIVATE_INIT(g_free);
