@@ -9,7 +9,7 @@
  *  error is retained for use by higher levels in the call stack.
  */
 
-// Copyright (C) 2017-2020 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2017-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 
@@ -56,30 +56,12 @@ void errinfo_free_with_report(
       const char *  func);
 
 Error_Info * errinfo_new(
-      int            status_code,
-      const char *   func);
-
-#define ERRINFO_NEW(_status_code) \
-   errinfo_new(_status_code, __func__)
-
-Error_Info * errinfo_new2(
       int            status_code,
       const char *   func,
       const char *   detail,
       ...);
 
 Error_Info * errinfo_new_with_cause(
-      int            status_code,
-      Error_Info *   cause,
-      const char *   func);
-
-Error_Info * errinfo_new_with_cause2(
-      int            status_code,
-      Error_Info *   cause,
-      const char *   func,
-      char *         detail);
-
-Error_Info * errinfo_new_with_cause3(
       int            status_code,
       Error_Info *   cause,
       const char *   func,
@@ -93,20 +75,6 @@ Error_Info * errinfo_new_chained(
 #endif
 
 Error_Info * errinfo_new_with_causes(
-      int            status_code,
-      Error_Info **  causes,
-      int            cause_ct,
-      const char *   func);
-
-Error_Info * errinfo_new_with_causes2(
-      int            status_code,
-      Error_Info **  causes,
-      int            cause_ct,
-      const char *   func,
-      char *         detail);
-
-Error_Info *
-errinfo_new_with_causes3(
       int            status_code,
       Error_Info **  causes,
       int            cause_ct,
@@ -132,10 +100,6 @@ void errinfo_set_status(
       int    rc);
 
 void errinfo_set_detail(
-      Error_Info *   erec,
-      char *         detail);
-
-void errinfo_set_detail3(
       Error_Info *   erec,
       const char *  detail_fmt,
       ...);
@@ -151,9 +115,7 @@ void errinfo_report(
       Error_Info *   erec,
       int            depth);
 
-
-void
-errinfo_report_details(Error_Info * erec, int depth);
+void errinfo_report_details(Error_Info * erec, int depth);
 
 char * errinfo_summary(
       Error_Info *   erec);
