@@ -11,7 +11,7 @@
  * - destination stack
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -148,10 +148,12 @@ void rpt_reset_indent_stack() {
 /** Given a logical indentation depth, returns the number of spaces
  *  of indentation to be used.
  *
- *  @param depth logical indentation depth
+ *  @param depth logical indentation depth, if < 0 perform no indentation
  *  @return number of indentation spaces
  */
 int rpt_get_indent(int depth) {
+   if (depth < 0)
+      depth = 0;
    Per_Thread_Settings * settings = get_thread_settings();
    int spaces_ct = DEFAULT_INDENT_SPACES_PER_DEPTH;
    if (settings->indent_spaces_stack_pos >= 0)
@@ -218,9 +220,10 @@ void rpt_debug_output_dest() {
     FILE * dest = rpt_cur_output_dest();
     char * addl = (dest == stdout) ? " (stdout)" : "";
     printf("(%s) output_dest_stack[%d] = %p %s\n",
-          __func__, settings->output_dest_stack_pos, dest, addl);
+          __func__, settings->output_dest_stack_pos, (void*)dest, addl);
 }
 
+
 /** Changes the current output destination, without saving
  * the current output destination on the destination stack.
  *
@@ -266,7 +269,7 @@ void rpt_nl() {
 void rpt_title(const char * title, int depth) {
    bool debug = false;
    if (debug)
-      printf("(%s) Writing to %p\n", __func__, rpt_cur_output_dest());
+      printf("(%s) Writing to %p\n", __func__, (void*)rpt_cur_output_dest());
    f0printf(rpt_cur_output_dest(), "%*s%s\n", rpt_get_indent(depth), "", title);
 }
 
@@ -474,7 +477,7 @@ int rpt_file_contents(const char * fn, bool verbose, int depth) {
 void rpt_str(const char * name, char * info, const char * val, int depth) {
    bool debug = false;
    if (debug)
-      printf("(%s) Writing to %p\n", __func__, rpt_cur_output_dest());
+      printf("(%s) Writing to %p\n", __func__, (void*)rpt_cur_output_dest());
 
    char infobuf[100];
    if (info)
