@@ -2,7 +2,7 @@
  *  String utility functions
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 
@@ -131,6 +131,12 @@ bool str_ends_with(const char * value_to_test, const char * suffix) {
    return result;
 }
 
+
+/** Tests if a string contains a substring.
+ *  @param value to test   string to examine
+ *  @param segment         substring to look for
+ *  @return starting position of substring, -1 if not found
+ */
 int str_contains(const char * value_to_test, const char * segment) {
    int result = -1;
    if (value_to_test && segment) {
@@ -442,7 +448,7 @@ Null_Terminated_String_Array strsplit(const char * str_to_split, const char * de
    char * token;
    // originally token assignment was in while() clause, but valgrind
    // complaining about uninitialized variable, trying to figure out why
-   token = strsep(&rest, delims);      // n. overwrites character found
+   token = strsep(&rest, delims);      // n. overwriteedid.cs character found
    while (token) {
       if (debug)
          printf("(%s) token: |%s|\n", __func__, token);
@@ -502,10 +508,10 @@ strsplit_maxlength(
    char * start = str_to_split2;
    char * str_to_split2_end = str_to_split2 + strlen(str_to_split);
    if (debug)
-      printf("(%s)x start=%p, str_to_split2_end=%p\n", __func__, start, str_to_split2_end);
+      printf("(%s)x start=%p, str_to_split2_end=%p\n", __func__, (void*)start, (void*)str_to_split2_end);
    while (start < str_to_split2_end) {
       if (debug)
-         printf("(%s) start=%p, str_to_split2_end=%p\n", __func__, start, str_to_split2_end);
+         printf("(%s) start=%p, str_to_split2_end=%p\n", __func__, (void*)start, (void*)str_to_split2_end);
       char * end = start + max_piece_length;
       if (end > str_to_split2_end)
          end = str_to_split2_end;
@@ -554,7 +560,7 @@ strsplit_maxlength(
 void ntsa_free(Null_Terminated_String_Array string_array, bool free_strings) {
    bool debug = false;
    if (debug)
-      printf("(%s) Freeing NTSA %p, free_strings=%s\n", __func__, string_array, sbool(free_strings) );
+      printf("(%s) Freeing NTSA %p, free_strings=%s\n", __func__, (void*) string_array, sbool(free_strings) );
    if (string_array) {
       if (free_strings) {
          int ndx = 0;
@@ -566,7 +572,7 @@ void ntsa_free(Null_Terminated_String_Array string_array, bool free_strings) {
          }
       }
       if (debug)
-         printf("(%s) Freeing string_array=%p\n", __func__, string_array);
+         printf("(%s) Freeing string_array=%p\n", __func__, (void*) string_array);
       free(string_array);
    }
 }
@@ -745,7 +751,7 @@ int  ntsa_find(  Null_Terminated_String_Array string_array, char * value) {
  */
 void ntsa_show(Null_Terminated_String_Array string_array) {
    assert(string_array);
-   printf("Null_Terminated_String_Array at %p:\n", string_array);
+   printf("Null_Terminated_String_Array at %p:\n", (void*) string_array);
    int ndx = 0;
    while (string_array[ndx]) {
       printf("  %p: |%s|\n", string_array[ndx], string_array[ndx]);
@@ -799,9 +805,8 @@ g_ptr_array_to_ntsa(
 /** Converts an ASCII string to upper case.  The original string is converted in place.
  *
  * @param  s string to force to upper case
- * @return converted string
  */
-char * strupper(char * s) {
+void strupper(char * s) {
    if (s) {     // check s not a null pointer
       char * p = s;
       while(*p) {
@@ -809,16 +814,14 @@ char * strupper(char * s) {
          p++;
       }
    }
-   return s;
 }
 
 
 /** Converts an ASCII string to lower case.  The original string is converted in place.
  *
  * @param  s string to force to lower case
- * @return converted string
  */
-char * strlower(char * s) {
+void strlower(char * s) {
    if (s) {     // check s not a null pointer
       char * p = s;
       while(*p) {
@@ -826,7 +829,6 @@ char * strlower(char * s) {
          p++;
       }
    }
-   return s;
 }
 
 
