@@ -1,6 +1,6 @@
 /** \file sysfs_filter_functions.c */
 
-// Copyright (C) 2021-2022 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2021-2023 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include <assert.h>
@@ -107,7 +107,28 @@ regex_t * get_compiled_regex(const char * pattern) {
 static const char * cardN_connector_pattern = "^card[0-9]+[-]";
 static const char * cardN_pattern = "^card[0-9]+$";
 static const char * D_00hh_pattern = "^[0-9]+-00[0-9a-fA-F]{2}$";
+static const char * i2c_N_pattern = "^i2c-([0-9]+)$";
 
+#ifdef FUTURE
+// requires testing
+bool eval_regex_with_matches(regex_t * re, const char * value, size_t max_matches, regmatch_t * pm ) {
+   bool debug = false;
+   if (debug)
+      printf("(%s) Starting. re=%p, value=|%s|\n", __func__, (void*)re, value);
+   int rc = regexec(
+          re,                   /* the compiled pattern */
+          value,                /* the subject string */
+          max_matches,
+          pm,
+          0
+       );
+   bool result = (rc  == 0) ? true : false;
+   if (debug)
+       printf("(%s) Returning %s. value=|%s|, regexec() returned %d\n",
+             __func__, sbool(result), value, rc);
+   return result;
+}
+#endif
 
 bool eval_regex(regex_t * re, const char * value) {
    bool debug = false;
@@ -153,6 +174,40 @@ bool compile_and_eval_regex(const char * pattern, const char * value) {
 }
 
 
+#ifdef FUTURE
+// to test
+bool compile_and_eval_regex_with_matches(
+      const char * pattern,
+      const char * value,
+      size_t       max_matches,
+      regmatch_t * pm)
+{
+   bool debug = false;
+   if (debug)
+      printf("(%s) Starting. pattern=|%s|, value=|%s|\n", __func__, pattern, value);
+   regex_t * re = get_compiled_regex(pattern);
+   // printf("(%s) forcing re = NULL\n", __func__);
+   // re = NULL;
+   if (!re) {
+      re = calloc(1, sizeof(regex_t));
+      if (debug)
+         printf("(%s) Allocated regex %p, compiling...\n", __func__, (void*)re);
+      int rc = regcomp(re, pattern, REG_EXTENDED);
+      if (rc != 0) {
+         printf("(%s) regcomp() returned %d\n", __func__, rc);
+         assert(rc == 0);
+      }
+      save_compiled_regex(pattern, re);
+   }
+   bool result = eval_regex_with_matches(re, value, max_matches, pm);
+   if (debug)
+      printf("(%s) Done. Returning %s\n", __func__, sbool(result));
+   return result;
+}
+#endif
+
+
+
 bool predicate_cardN(const char * value) {
    bool debug = false;
    if (debug)
@@ -181,10 +236,44 @@ bool predicate_cardN_connector(const char * value) {
 }
 
 
-bool startswith_i2c(const char * value) {
-   return str_starts_with(value, "i2c-");
+bool predicate_i2c_N(const char * value) {
+   bool debug = false;
+   bool b1 = compile_and_eval_regex(i2c_N_pattern, value);
+   if (debug)
+      printf("(%s) value=|%s|, returning %s\n", __func__, value, sbool( b1));
+   return b1;
 }
 
+
+#ifdef FUTURE
+// untested
+int match_i2c_N(const char * value) {
+   bool debug = true;
+   regmatch_t matchpos;
+   int result = -1;
+   if (compile_and_eval_regex(i2c_N_pattern, value, &matchpos)) {
+      // pattern match ensures that the character after the end of the match is NULL,
+      // and that atoi always succeeds
+      result = atoi(value + matchpos.rm_so);
+   }
+   if (debug)
+      printf("(%s) value=|%s|, returning %d\n", __func__, value, result);
+   return result;
+}
+
+
+int match_dev_i2c_N(const char * value) {
+   bool debug = true;
+   int result = -1;
+   if (str_starts_with(value,  "/dev/")) {
+      result = match_i2c_N(value+5);
+   }
+   if (debug)
+      printf("(%s) value=|%s|, returning %d\n", __func__, value, result);
+   return result;
+}
+#endif
+
 bool class_display_device_predicate(const char * value) {
    return str_starts_with(value, "0x03");
 }
@@ -232,20 +321,22 @@ bool dirname_starts_with(const char * dirname, const char * val) {
    return result;
 #endif
 
+
 // for e.g. i2c-3
-bool is_i2cN(const char * dirname, const char * val) {
-   // bool debug = false;
-   // DBGMSF(debug, "dirname=%s, val_fn=%s", dirname, val);
-   bool result = str_starts_with(dirname, "i2c-");
-   // DBGMSF(debug, "Returning %s", sbool(result));
+bool is_i2cN_dir(const char * dirname, const char * fn_ignored) {
+   bool debug = false;
+   bool result = predicate_i2c_N(dirname);
+   if (debug)
+      printf("(%s) dirname=%s, fn_ignored=%s, returning %s\n", __func__, dirname, fn_ignored, sbool(result));
    return result;
 }
 
-bool is_drm_dp_aux_subdir(const char * dirname, const char * val) {
-   // bool debug = false;
-   // DBGMSF(debug, "dirname=%s, val=%s", dirname, val);
+
+bool is_drm_dp_aux_subdir(const char * dirname, const char * fn_ignored) {
+   bool debug = false;
    bool result = str_starts_with(dirname, "drm_dp_aux");
-   // DBGMSF(debug, "Returning %s", sbool(result));
+   if (debug)
+      printf("(%s) dirname=%s, fn_ignored=%s, returning %s\n", __func__, dirname, fn_ignored, sbool(result));
    return result;
 }
 
@@ -257,27 +348,25 @@ bool is_card_connector_dir(const char * dirname, const char * simple_fn) {
 
 // for e.g. card0
 bool is_cardN_dir(const char * dirname, const char * simple_fn) {
-   bool result = str_starts_with(simple_fn, "card");
+   bool result = predicate_cardN(simple_fn);
+// bool result = str_starts_with(simple_fn, "card");
    return result;
 }
 
+
 bool is_drm_dir(const char * dirname, const char * simple_fn) {
    bool result = streq(simple_fn, "drm");
    return result;
 }
 
-bool is_i2cN_dir(const char * dirname, const char * simple_fn) {
-   bool result = str_starts_with(simple_fn, "i2c-");
-   return result;
-}
-
 // does dirname/simple_fn have attribute class with value display controller or docking station?
 bool has_class_display_or_docking_station(
       const char * dirname, const char * simple_fn)
 {
-   // bool debug = false;
+   bool debug = false;
    bool result = false;
-   // DBGMSF(debug, "Starting. dirname=%s, simple_fn=%s", dirname, simple_fn);
+   if (debug)
+      printf("(%s) Starting. dirname=%s, simple_fn=%s\n", __func__, dirname, simple_fn);
    char * class_val = NULL;
    int    iclass = 0;
    int    top_byte = 0;
@@ -288,8 +377,8 @@ bool has_class_display_or_docking_station(
             result = true;
       }
    }
-   // DBGMSF(debug, "class_val = %s, top_byte = 0x%02x, result=%s",
-   //               class_val, top_byte, sbool(result) );
+   if (debug)
+      printf("(%s) class_val = %s, top_byte = 0x%02x, result=%s\n", __func__, class_val, top_byte, sbool(result) );
    free(class_val);
    return result;
 }
