@@ -13,7 +13,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#include "coredefs_base.h"
 #include "file_util.h"
+#include "i2c_util.h"
 #include "report_util.h"
 #include "string_util.h"
 #include "subprocess_util.h"
@@ -71,8 +73,7 @@ is_module_loaded_using_sysfs(
  *  Caller is responsible for freeing returned value
  */
 char *
-get_i2c_device_sysfs_name(
-      int busno)
+get_i2c_device_sysfs_name(int busno)
 {
    char workbuf[50];
    snprintf(workbuf, 50, "/sys/bus/i2c/devices/i2c-%d/name", busno);
@@ -93,7 +94,7 @@ get_i2c_device_sysfs_name(
  *  Caller is responsible for freeing returned value
  */
 char *
-get_i2c_device_sysfs_driver(int busno) {
+get_i2c_sysfs_driver_by_busno(int busno) {
    char * driver_name = NULL;
    char workbuf[100];
    snprintf(workbuf, 100, "/sys/bus/i2c/devices/i2c-%d/device/driver/module", busno);
@@ -107,6 +108,56 @@ get_i2c_device_sysfs_driver(int busno) {
 }
 
 
+/** Gets the name of the driver for a /dev/i2c-N device,
+ *  i.e. the basename of /sys/bus/i2c/devices/i2c-n/device/driver/module
+ *
+ *  \param  device_name   e.g. /dev/i2c-n
+ *  \return newly allocated string containing driver name
+ *          NULL if not found
+ *
+ *  \remark
+ *  Caller is responsible for freeing returned value
+ */
+char *
+get_i2c_sysfs_driver_by_device_name(char * device_name) {
+   bool debug = false;
+   if (debug)
+      printf("(%s) Starting. device_name = %s", __func__, device_name);
+   char * driver_name = NULL;
+   int busno = extract_number_after_hyphen(device_name);
+   if (busno >= 0) {
+      driver_name = get_i2c_sysfs_driver_by_busno(busno);
+   }
+   if (debug)
+      printf("(%s) Done. Returning: %s", __func__, driver_name);
+   return driver_name;
+}
+
+
+/** Gets the name of the driver for a /dev/i2c-N device, specified by its file descriptor.
+ *  i.e. the basename of /sys/bus/i2c/devices/i2c-n/device/driver/module
+ *
+ *  \param  fd   file descriptor
+ *  \return newly allocated string containing driver name
+ *          NULL if not found
+ *
+ *  \remark
+ *  Caller is responsible for freeing returned value
+ */
+char *
+get_i2c_sysfs_driver_by_fd(int fd) {
+   bool debug = false;
+   char * driver_name = NULL;
+   int busno = extract_number_after_hyphen(filename_for_fd_t(fd));
+   if (busno >= 0) {
+      driver_name = get_i2c_sysfs_driver_by_busno(busno);
+   }
+   if (debug)
+      printf("(%s) fd=%d, returning %s\n", __func__, fd, driver_name);
+   return driver_name;
+}
+
+
 /** Gets the class of an I2C device,
  *  i.e. /sys/bus/i2c/devices/i2c-n/device/class
  *  or   /sys/bus/i2c/devices/i2c-n/device/device/device/class
@@ -115,7 +166,8 @@ get_i2c_device_sysfs_driver(int busno) {
  *  \return device class
  *          0 if not found (should never occur)
  */
-uint32_t get_i2c_device_sysfs_class(int busno) {
+uint32_t
+get_i2c_device_sysfs_class(int busno) {
    uint32_t result = 0;
    char workbuf[100];
    snprintf(workbuf, 100, "/sys/bus/i2c/devices/i2c-%d/device", busno);
@@ -138,20 +190,6 @@ uint32_t get_i2c_device_sysfs_class(int busno) {
 }
 
 
-#ifdef UNUSED
-static bool is_smbus_device_using_sysfs(int busno) {
-   char * name = get_i2c_device_sysfs_name(busno);
-
-   bool result = false;
-   if (name && str_starts_with(name, "SMBus"))
-      result = true;
-   free(name);
-   // DBGMSG("busno=%d, returning: %s", busno, bool_repr(result));
-   return result;
-}
-#endif
-
-
 static bool
 ignorable_i2c_device_sysfs_name(const char * name, const char * driver) {
    bool result = false;
@@ -197,7 +235,7 @@ sysfs_is_ignorable_i2c_device(int busno) {
    // If not found, then base the result on the device's class.
 
    char * name = get_i2c_device_sysfs_name(busno);
-   char * driver = get_i2c_device_sysfs_driver(busno);
+   char * driver = get_i2c_sysfs_driver_by_busno(busno);
    if (name)
       result = ignorable_i2c_device_sysfs_name(name, driver);
    if (debug)
@@ -223,94 +261,8 @@ sysfs_is_ignorable_i2c_device(int busno) {
 }
 
 
-#ifdef UNUSED
-int get_sysfs_drm_edid_count() {
-   int ival = 0;
-   GPtrArray * output = execute_shell_cmd_collect("ls /sys/class/drm/card*-*/edid | wc -w");
-   if (output) {
-      char * s = g_ptr_array_index(output, 0);
-#ifndef NDEBUG
-      bool ok =
-#endif
-      str_to_int(s, &ival, 10);
-      assert(ok);
-      g_ptr_array_free(output, true);
-   }
-   return ival;
-}
-#endif
-
-
-#ifdef OLD
-// TODO: rewrite using sys functions
-Byte_Bit_Flags get_sysfs_drm_card_numbers()
-{
-   const char * dname =
-#ifdef TARGET_BSD
-                    "/compat/linux/sys/class/drm";
-#else
-                    "/sys/class/drm";
-#endif
-
-   bool debug = false;
-   if (debug)
-      printf("(%s) Starting. dname=|%s|\n", __func__, dname);
-
-   Byte_Bit_Flags result = bbf_create();
-
-   DIR           *dir1;
-   char          dnbuf[90];
-   const int     cardname_sz = 20;
-   char          cardname[cardname_sz];
-
-   int depth = 0;
-   int d1    = depth+1;
-
-   // rpt_vstring(depth, "Examining (W) %s...", dname);
-   dir1 = opendir(dname);
-   if (!dir1) {
-      rpt_vstring(depth, "Unable to open directory %s: %s",
-                     dname, strerror(errno));
-   }
-   else {
-      closedir(dir1);
-      int cardno = 0;
-      for (;;cardno++) {
-         snprintf(cardname, cardname_sz, "card%d", cardno);
-         snprintf(dnbuf, 80, "%s/%s", dname, cardname);
-         dir1 = opendir(dnbuf);
-         if (debug)
-            printf("(%s) dnbuf=%s", __func__, dnbuf);
-         if (dir1) {
-            bbf_insert(result, cardno);
-            closedir(dir1);
-         }
-         else {
-            //  rpt_vstring(d1, "Unable to open sysfs directory %s: %s\n", dnbuf, strerror(errno));
-            break;
-         }
-      }
-
-      if (bbf_count_set(result) == 0) {
-         rpt_vstring(d1, "No drm class video cards found in %s", dname);
-      }
-   }
-#ifdef OLD
-   char * s = bbf_to_string(result);
-   if (debug)
-      printf("(%s) Done.     Returning: %s\n", __func__, s);
-   free(s);
-#endif
-   if (debug)
-      printf("(%s) Done.     Returning: %s\n", __func__, bbf_to_string(result));
-
-   return result;
-}
-#endif
-
-
-static
-void do_sysfs_drm_card_number_dir(
+static void
+do_sysfs_drm_card_number_dir(
             const char * dirname,     // <device>/drm
             const char * simple_fn,   // card0, card1, etc.
             void *       data,
@@ -328,7 +280,8 @@ void do_sysfs_drm_card_number_dir(
 }
 
 
-Bit_Set_256 get_sysfs_drm_card_numbers() {
+Bit_Set_256
+get_sysfs_drm_card_numbers() {
    bool debug = false;
    char * dname =
  #ifdef TARGET_BSD
@@ -349,6 +302,3 @@ Bit_Set_256 get_sysfs_drm_card_numbers() {
       printf("(%s) Done.    Returning DRM card numbers: %s\n", __func__, bs256_to_string_decimal(result, "", ", "));
    return result;
  }
-
-
-
