@@ -13,9 +13,17 @@
 #include "data_structures.h"
 
 char *
-get_i2c_device_sysfs_driver(
+get_i2c_sysfs_driver_by_busno(
       int busno);
 
+char *
+get_i2c_sysfs_driver_by_device_name(
+      char * device_name);
+
+char *
+get_i2c_sysfs_driver_by_fd(
+      int fd);
+
 uint32_t
 get_i2c_device_sysfs_class(
       int busno);
@@ -32,11 +40,6 @@ bool
 sysfs_is_ignorable_i2c_device(
       int busno);
 
-#ifdef UNUSED
-int
-get_sysfs_drm_edid_count();
-#endif
-
 Bit_Set_256
 get_sysfs_drm_card_numbers();
 
