@@ -2,7 +2,7 @@
  *  Parse the capabilities string returned by DDC, query the parsed data structure.
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -18,15 +18,19 @@
 #include "util/string_util.h"
 
 #include "base/core.h"
+#include "base/ddc_command_codes.h"
 #include "base/displays.h"
+#include "base/rtti.h"
 #include "base/vcp_version.h"
 
-#include "vcp/ddc_command_codes.h"
 #include "vcp/parsed_capabilities_feature.h"
 #include "vcp/vcp_feature_codes.h"
 
 #include "vcp/parse_capabilities.h"
 
+
+static DDCA_Trace_Group  TRACE_GROUP = DDCA_TRC_NONE;
+
 #undef CAPABILITIES_TESTS
 // #define CAPABILITIES_TESTS
 
@@ -140,9 +144,9 @@ void free_parsed_capabilities(Parsed_Capabilities * pcaps) {
 
 /* Point to the first non-space character in a string.
  *
- * \param  s   pointer to string
+ * @param  s   pointer to string
  * \parsm  len length of string
- * \return pointer to first non-space character of string,
+ * @return pointer to first non-space character of string,
  *         end of string if not found
  */
 char * ltrim(char * s, int len) {
@@ -157,10 +161,10 @@ char * ltrim(char * s, int len) {
 /** Finds the matching closing parenthesis for the
  *  current open parenthesis.
  *
- *  \param start    first character to examine (must be '(')
- *  \param end      points to end of string, i.e. the byte
+ *  @param start    first character to examine (must be '(')
+ *  @param end      points to end of string, i.e. the byte
  *                  after the last character to examine
- *  \return pointer pointer to closing parenthesis,
+ *  @return pointer pointer to closing parenthesis,
  *          end if closing parenthesis not found
  */
 
@@ -218,17 +222,17 @@ update_validity(
 /** Parses the value of the cmds segment, which is a list of 2 character values
  *  separated by spaces.
  *
- * \param   start    start of values
- * \param   len      segment length
- * \param   messages accumulates error messages
- * \return  #Byte_Value_Array indicating command values seen,
+ * @param   start    start of values
+ * @param   len      segment length
+ * @param   messages accumulates error messages
+ * @return  #Byte_Value_Array indicating command values seen,
  *          NULL if a parsing error
  *
- *  \remark
+ *  @remark
  *  Alternatively, return a ByteBitFlag value, or pass a
  *  preallocted ByteBitFlag instance
  *
- *  \remark
+ *  @remark
  *  On every monitor tested, the values are separated by spaces.
  *  However, per the Access Bus spec, Section 7, values need not be separated by spaces,
  *  e.g. 010203 is valid
@@ -532,9 +536,9 @@ struct {
 
 /** Extract the next top level segment of the capabilities string.
  *
- *  \param  start   current position in the capabilities string
- *  \param  len     length of remainder of capabilities string
- *  \return pointer to newly allocated Capabilities_Segment describing the segment
+ *  @param  start   current position in the capabilities string
+ *  @param  len     length of remainder of capabilities string
+ *  @return pointer to newly allocated Capabilities_Segment describing the segment
  *          It is the responsibility of the caller to free the returned struct,
  *          BUT NOT THE LOCATIONS IT ADDRESSES
  */
@@ -632,9 +636,10 @@ Parsed_Capabilities * parse_capabilities(
 {
    assert(buf_start);
    bool debug = false;
-   if (debug) {
-      // hex_dump((Byte*)buf_start, buf_len);
-      DBGMSF(debug, "Starting. buf_len=%d, buf_start->|%.*s|", buf_len, buf_len, buf_start);
+   DBGTRC_STARTING(debug, TRACE_GROUP, "buf_len=%d, buf_start=%p->|%.*s|",
+                                       buf_start, buf_len, buf_len, buf_start);
+   if ( IS_DBGTRC(debug, TRACE_GROUP) ) {
+      rpt_hex_dump((Byte*)buf_start, buf_len, 1);
    }
    
    // right trim white space
@@ -751,11 +756,7 @@ Parsed_Capabilities * parse_capabilities(
    }
 
 bye:
-   if (debug) {
-      dbgrpt_parsed_capabilities(pcaps, 0);  // handles NULL
-      DBGMSF(debug, "Done.     Returning %p", pcaps);
-   }
-
+   DBGTRC_RET_STRUCT(debug, DDCA_TRC_NONE, "Parsed_Capabilities", dbgrpt_parsed_capabilities, pcaps);
    return pcaps;
 }
 
@@ -788,9 +789,9 @@ Parsed_Capabilities* parse_capabilities_string(
  *  @param pcaps           pointer to #Parsed_Capabilities
  *  @param readable_only   restrict returned list to readable features
  *
- *  @return  #Byte_Bit_Flags value indicating features found
+ *  @return  #Bit_Set_256  value indicating features found
  */
-Byte_Bit_Flags get_parsed_capabilities_feature_ids(
+Bit_Set_256 get_parsed_capabilities_feature_ids(
       Parsed_Capabilities * pcaps,
       bool                  readable_only)
 {
@@ -799,7 +800,8 @@ Byte_Bit_Flags get_parsed_capabilities_feature_ids(
    DBGMSF(debug, "Starting. readable_only=%s, feature count=%d",
                  sbool(readable_only), pcaps->vcp_features->len);
 
-   Byte_Bit_Flags flags = bbf_create();
+   // Byte_Bit_Flags flags = bbf_create();
+   Bit_Set_256 flags = EMPTY_BIT_SET_256;
    if (pcaps->vcp_features) {    // pathological case of 0 length capabilities string
       for (int ndx = 0; ndx < pcaps->vcp_features->len; ndx++) {
          Capabilities_Feature_Record * frec = g_ptr_array_index(pcaps->vcp_features, ndx);
@@ -814,11 +816,12 @@ Byte_Bit_Flags get_parsed_capabilities_feature_ids(
                free_synthetic_vcp_entry(vfte);
          }
          if (add_feature_to_list)
-            bbf_set(flags, frec->feature_id);
+            // bbf_insert(flags, frec->feature_id);
+            flags = bs256_insert(flags, frec->feature_id);
       }
    }
 
-   DBGMSF(debug, "Returning Byte_Bit_Flags: %s", bbf_to_string(flags, NULL, 0));
+   DBGMSF(debug, "Returning Bit_Set_256: %s", bs256_to_string(flags, "x", ", ") );
    return flags;
 }
 
@@ -877,3 +880,11 @@ void test_parse_caps() {
 }
 #endif
 
+
+/** Module initialization */
+void init_parse_capabilities() {
+   RTTI_ADD_FUNC(parse_capabilities);
+}
+
+
+
