@@ -3,7 +3,7 @@
  *  Tables describing VCP feature codes and functions to interpret those tables
  */
 
-// Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef VCP_FEATURE_CODES_H_
@@ -21,12 +21,11 @@
 #include "base/core.h"
 #include "base/displays.h"
 #include "base/ddc_packets.h"
-#include "base/feature_sets.h"
 #include "base/feature_metadata.h"
+#include "base/feature_set_ref.h"
 
 #include "vcp/vcp_feature_values.h"
 
-
 bool default_table_feature_detail_function(
         Buffer *                data,
         DDCA_MCCS_Version_Spec  vcp_version,
@@ -296,12 +295,14 @@ get_feature_name_by_id_and_vcp_version(
       DDCA_Vcp_Feature_Code      feature_code,
       DDCA_MCCS_Version_Spec     vspec);
 
+#ifdef MCCS_VERSION_ID
 Display_Feature_Metadata *
 get_version_feature_info_by_version_id_dfm(
       DDCA_Vcp_Feature_Code   feature_code,
       DDCA_MCCS_Version_Id    mccs_version_id,
       bool                    with_default,
       bool                    version_sensitive);
+#endif
 
 Display_Feature_Metadata *
 get_version_feature_info_by_vspec_dfm(
